@@ -19,9 +19,17 @@ var State = {
     gc();
     print("true"); // indicates success
   },
-  addFun : function(newFun) {
+  addFun : function(newFun, option) {
     // Compile to a function and add it to funs array
-    State.funs.push(Couch.compileFunction(newFun, {views : {lib : State.lib}}));
+    switch (option) {
+      case 'nouveau':
+        var sandbox = create_nouveau_sandbox();
+        break;
+      default:
+        var sandbox = create_dreyfus_sandbox();
+        break;
+    }
+    State.funs.push(Couch.compileFunction(newFun, {views : {lib : State.lib}}, undefined, sandbox));
     print("true");
   },
   addLib : function(lib) {
