@@ -19,7 +19,6 @@
 -include_lib("couch/include/couch_db.hrl").
 -include("couch_db_int.hrl").
 
--define(IDLE_LIMIT_DEFAULT, 61000).
 % 10 GiB
 -define(DEFAULT_MAX_PARTITION_SIZE, 16#280000000).
 
@@ -34,7 +33,6 @@
 
 init({Engine, DbName, FilePath, Options0}) ->
     erlang:put(io_priority, {db_update, DbName}),
-    update_idle_limit_from_config(),
     DefaultSecObj = default_security_object(DbName),
     Options = [{default_security_object, DefaultSecObj} | Options0],
     try
@@ -51,7 +49,7 @@ init({Engine, DbName, FilePath, Options0}) ->
         % couch_db:validate_doc_update, which loads them lazily.
         NewDb = Db#db{main_pid = self()},
         proc_lib:init_ack({ok, NewDb}),
-        gen_server:enter_loop(?MODULE, [], NewDb, idle_limit())
+        gen_server:enter_loop(?MODULE, [], NewDb)
     catch
         throw:InitError ->
             proc_lib:init_ack(InitError)
@@ -63,39 +61,39 @@ terminate(Reason, Db) ->
     ok.
 
 handle_call(get_db, _From, Db) ->
-    {reply, {ok, Db}, Db, idle_limit()};
+    {reply, {ok, Db}, Db};
 handle_call(start_compact, _From, Db) ->
-    {noreply, NewDb, _Timeout} = handle_cast(start_compact, Db),
-    {reply, {ok, NewDb#db.compactor_pid}, NewDb, idle_limit()};
+    {noreply, NewDb} = handle_cast(start_compact, Db),
+    {reply, {ok, NewDb#db.compactor_pid}, NewDb};
 handle_call(compactor_pid, _From, #db{compactor_pid = Pid} = Db) ->
-    {reply, Pid, Db, idle_limit()};
+    {reply, Pid, Db};
 handle_call(cancel_compact, _From, #db{compactor_pid = nil} = Db) ->
-    {reply, ok, Db, idle_limit()};
+    {reply, ok, Db};
 handle_call(cancel_compact, _From, #db{compactor_pid = Pid} = Db) ->
     unlink(Pid),
     exit(Pid, kill),
     couch_server:delete_compaction_files(Db#db.name),
     Db2 = Db#db{compactor_pid = nil},
     ok = couch_server:db_updated(Db2),
-    {reply, ok, Db2, idle_limit()};
+    {reply, ok, Db2};
 handle_call({set_security, NewSec}, _From, #db{} = Db) ->
     {ok, NewDb} = couch_db_engine:set_security(Db, NewSec),
     NewSecDb = commit_data(NewDb#db{
         security = NewSec
     }),
     ok = couch_server:db_updated(NewSecDb),
-    {reply, ok, NewSecDb, idle_limit()};
+    {reply, ok, NewSecDb};
 handle_call({set_revs_limit, Limit}, _From, Db) ->
     {ok, Db2} = couch_db_engine:set_revs_limit(Db, Limit),
     Db3 = commit_data(Db2),
     ok = couch_server:db_updated(Db3),
-    {reply, ok, Db3, idle_limit()};
+    {reply, ok, Db3};
 handle_call({set_purge_infos_limit, Limit}, _From, Db) ->
     {ok, Db2} = couch_db_engine:set_purge_infos_limit(Db, Limit),
     ok = couch_server:db_updated(Db2),
-    {reply, ok, Db2, idle_limit()};
+    {reply, ok, Db2};
 handle_call({purge_docs, [], _}, _From, Db) ->
-    {reply, {ok, []}, Db, idle_limit()};
+    {reply, {ok, []}, Db};
 handle_call({purge_docs, PurgeReqs0, Options}, _From, Db) ->
     % Filter out any previously applied updates during
     % internal replication
@@ -116,11 +114,11 @@ handle_call({purge_docs, PurgeReqs0, Options}, _From, Db) ->
                 )
         end,
     {ok, NewDb, Replies} = purge_docs(Db, PurgeReqs),
-    {reply, {ok, Replies}, NewDb, idle_limit()};
+    {reply, {ok, Replies}, NewDb};
 handle_call(Msg, From, Db) ->
     case couch_db_engine:handle_db_updater_call(Msg, From, Db) of
         {reply, Resp, NewDb} ->
-            {reply, Resp, NewDb, idle_limit()};
+            {reply, Resp, NewDb};
         Else ->
             Else
     end.
@@ -128,7 +126,7 @@ handle_call(Msg, From, Db) ->
 handle_cast({load_validation_funs, ValidationFuns}, Db) ->
     Db2 = Db#db{validate_doc_funs = ValidationFuns},
     ok = couch_server:db_updated(Db2),
-    {noreply, Db2, idle_limit()};
+    {noreply, Db2};
 handle_cast(start_compact, Db) ->
     case Db#db.compactor_pid of
         nil ->
@@ -146,16 +144,14 @@ handle_cast(start_compact, Db) ->
             couch_log:Level("Starting compaction for db \"~s\" at ~p", Args),
             {ok, Db2} = couch_db_engine:start_compaction(Db),
             ok = couch_server:db_updated(Db2),
-            {noreply, Db2, idle_limit()};
+            {noreply, Db2};
         _ ->
             % compact currently running, this is a no-op
-            {noreply, Db, idle_limit()}
+            {noreply, Db}
     end;
 handle_cast({compact_done, _Engine, CompactInfo}, #db{} = OldDb) ->
     {ok, NewDb} = couch_db_engine:finish_compaction(OldDb, CompactInfo),
     {noreply, NewDb};
-handle_cast(wakeup, Db) ->
-    {noreply, Db, idle_limit()};
 handle_cast(Msg, #db{name = Name} = Db) ->
     couch_log:error(
         "Database `~s` updater received unexpected cast: ~p",
@@ -213,40 +209,20 @@ handle_info(
                     false ->
                         Db2
                 end,
-            {noreply, Db3, hibernate_if_no_idle_limit()}
+            {noreply, Db3, hibernate}
     catch
         throw:retry ->
             [catch (ClientPid ! {retry, self()}) || ClientPid <- Clients],
-            {noreply, Db, hibernate_if_no_idle_limit()}
+            {noreply, Db, hibernate}
     end;
 handle_info({'EXIT', _Pid, normal}, Db) ->
-    {noreply, Db, idle_limit()};
+    {noreply, Db};
 handle_info({'EXIT', _Pid, Reason}, Db) ->
     {stop, Reason, Db};
-handle_info(timeout, #db{name = DbName} = Db) ->
-    IdleLimitMSec = update_idle_limit_from_config(),
-    case couch_db:is_idle(Db) of
-        true ->
-            LastActivity = couch_db_engine:last_activity(Db),
-            DtMSec = timer:now_diff(os:timestamp(), LastActivity) div 1000,
-            MSecSinceLastActivity = max(0, DtMSec),
-            case MSecSinceLastActivity > IdleLimitMSec of
-                true ->
-                    ok = couch_server:close_db_if_idle(DbName);
-                false ->
-                    ok
-            end;
-        false ->
-            ok
-    end,
-    % Send a message to wake up and then hibernate. Hibernation here is done to
-    % force a thorough garbage collection.
-    gen_server:cast(self(), wakeup),
-    {noreply, Db, hibernate};
 handle_info(Msg, Db) ->
     case couch_db_engine:handle_db_updater_info(Msg, Db) of
         {noreply, NewDb} ->
-            {noreply, NewDb, idle_limit()};
+            {noreply, NewDb};
         Else ->
             Else
     end.
@@ -942,33 +918,6 @@ default_security_object(_DbName) ->
             []
     end.
 
-% These functions rely on using the process dictionary. This is
-% usually frowned upon however in this case it is done to avoid
-% changing to a different server state record. Once PSE (Pluggable
-% Storage Engine) code lands this should be moved to the #db{} record.
-update_idle_limit_from_config() ->
-    Default = integer_to_list(?IDLE_LIMIT_DEFAULT),
-    IdleLimit =
-        case config:get("couchdb", "idle_check_timeout", Default) of
-            "infinity" ->
-                infinity;
-            Milliseconds ->
-                list_to_integer(Milliseconds)
-        end,
-    put(idle_limit, IdleLimit),
-    IdleLimit.
-
-idle_limit() ->
-    get(idle_limit).
-
-hibernate_if_no_idle_limit() ->
-    case idle_limit() of
-        infinity ->
-            hibernate;
-        Timeout when is_integer(Timeout) ->
-            Timeout
-    end.
-
 -ifdef(TEST).
 -include_lib("eunit/include/eunit.hrl").
 
