@@ -21,7 +21,11 @@
 -define(SIZE_BLOCK, 16#1000).
 -define(PREFIX_SIZE, 5).
 -define(DEFAULT_READ_COUNT, 1024).
--define(WRITE_XXHASH_CHECKSUMS_DEFAULT, false).
+-define(WRITE_XXHASH_CHECKSUMS_DEFAULT, true).
+
+-define(USE_CFILE_DEFAULT, true).
+-define(CFILE_SKIP_IOQ_DEFAULT, false).
+-define(CFILE_HANDLE, cfile_handle).
 
 -type block_id() :: non_neg_integer().
 -type location() :: non_neg_integer().
@@ -32,7 +36,7 @@
     is_sys,
     eof = 0,
     db_monitor,
-    pread_limit = 0
+    filepath
 }).
 
 % public API
@@ -45,7 +49,6 @@
 -export([append_terms/2, append_terms/3]).
 -export([write_header/2, read_header/1]).
 -export([delete/2, delete/3, nuke_dir/2, init_delete_dir/1]).
--export([last_read/1]).
 
 % gen_server callbacks
 -export([init/1, terminate/2, format_status/2]).
@@ -188,11 +191,49 @@ pread_binaries(Fd, PosList) ->
     ZipFun = fun(Pos, {IoList, Checksum}) ->
         verify_checksum(Fd, Pos, iolist_to_binary(IoList), Checksum, false)
     end,
-    case ioq:call(Fd, {pread_iolists, PosList}, erlang:get(io_priority)) of
+    case pread_iolists(Fd, PosList) of
         {ok, DataAndChecksums} -> {ok, lists:zipwith(ZipFun, PosList, DataAndChecksums)};
         Error -> Error
     end.
 
+pread_iolists(Fd, PosList) ->
+    IoqPriority = erlang:get(io_priority),
+    IoqMsg = {pread_iolists, PosList},
+    case {get_cfile(Fd), cfile_skip_ioq()} of
+        {undefined, _} ->
+            % No cfile, that's fine, do what we always did
+            ioq:call(Fd, IoqMsg, IoqPriority);
+        {#file{} = CFile, true} ->
+            % Skip the IOQ if we have a cfile handle. Use this option on a
+            % system with enough RAM for the page cache and plenty of IO
+            % bandwidth
+            parallel_pread(CFile, PosList);
+        {#file{} = CFile, false} ->
+            % Use parallel preads only if the request would be bypassed by the
+            % IOQ. All three compatible ioqs (the two from the
+            % apache/couchdb-ioq, and the source default one) currently do not
+            % know how to call a function, they all expect to send a
+            % '$gen_call' message to a gen_server. Until we figure out how
+            % teach the IOQ(s) to call an MFA we can let them keep calling the
+            % main file descriptor gen_server.
+            case ioq:bypass(IoqMsg, IoqPriority) of
+                true -> parallel_pread(CFile, PosList);
+                false -> ioq:call(Fd, IoqMsg, IoqPriority)
+            end
+    end.
+
+parallel_pread(#file{} = CFile, PosList) when is_list(PosList) ->
+    try
+        pread(CFile, PosList)
+    catch
+        % Catch the early return since we're bypassing the gen_server
+        throw:{stop, Error, _, _} ->
+            Error
+    end.
+
+cfile_skip_ioq() ->
+    config:get_boolean("couchdb", "cfile_skip_ioq", ?CFILE_SKIP_IOQ_DEFAULT).
+
 append_terms(Fd, Terms) ->
     append_terms(Fd, Terms, []).
 
@@ -219,9 +260,12 @@ append_binaries(Fd, Bins) when is_list(Bins) ->
 %%  or {error, Reason}.
 %%----------------------------------------------------------------------
 
-% length in bytes
+% length in bytes.
 bytes(Fd) ->
-    gen_server:call(Fd, bytes, infinity).
+    case get_cfile(Fd) of
+        undefined -> gen_server:call(Fd, bytes, infinity);
+        #file{} = CFile -> eof(CFile)
+    end.
 
 %%----------------------------------------------------------------------
 %% Purpose: Truncate a file to the number of bytes.
@@ -401,17 +445,12 @@ init_status_error(ReturnPid, Ref, Error) ->
     ReturnPid ! {Ref, self(), Error},
     ignore.
 
-last_read(Fd) when is_pid(Fd) ->
-    Now = os:timestamp(),
-    couch_util:process_dict_get(Fd, read_timestamp, Now).
-
 % server functions
 
 init({Filepath, Options, ReturnPid, Ref}) ->
     OpenOptions = file_open_options(Options),
-    Limit = get_pread_limit(),
     IsSys = lists:member(sys_db, Options),
-    update_read_timestamp(),
+    File = #file{filepath = Filepath, is_sys = IsSys},
     case lists:member(create, Options) of
         true ->
             filelib:ensure_dir(Filepath),
@@ -432,7 +471,7 @@ init({Filepath, Options, ReturnPid, Ref}) ->
                                     ok = fsync(Fd),
                                     maybe_track_open_os_files(Options),
                                     erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                                    {ok, #file{fd = Fd, is_sys = IsSys, pread_limit = Limit}};
+                                    {ok, dup(File#file{fd = Fd})};
                                 false ->
                                     ok = file:close(Fd),
                                     init_status_error(ReturnPid, Ref, {error, eexist})
@@ -440,7 +479,7 @@ init({Filepath, Options, ReturnPid, Ref}) ->
                         false ->
                             maybe_track_open_os_files(Options),
                             erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                            {ok, #file{fd = Fd, is_sys = IsSys, pread_limit = Limit}}
+                            {ok, dup(File#file{fd = Fd})}
                     end;
                 Error ->
                     init_status_error(ReturnPid, Ref, Error)
@@ -457,7 +496,7 @@ init({Filepath, Options, ReturnPid, Ref}) ->
                             maybe_track_open_os_files(Options),
                             {ok, Eof} = file:position(Fd, eof),
                             erlang:send_after(?INITIAL_WAIT, self(), maybe_close),
-                            {ok, #file{fd = Fd, eof = Eof, is_sys = IsSys, pread_limit = Limit}};
+                            {ok, dup(File#file{fd = Fd, eof = Eof})};
                         Error ->
                             init_status_error(ReturnPid, Ref, Error)
                     end;
@@ -490,29 +529,20 @@ terminate(_Reason, #file{fd = Fd}) ->
 
 handle_call(close, _From, #file{fd = Fd} = File) ->
     {stop, normal, file:close(Fd), File#file{fd = nil}};
+handle_call({pread_iolist, Pos}, _From, File) ->
+    % Compatibility clause. Remove after upgrading to next release after 3.5.0
+    % Attachment streams may be opened from remote nodes during the upgrade on
+    % a mixed cluster
+    Result =
+        case pread(File, [Pos]) of
+            {ok, [{IoList, Checksum}]} -> {ok, IoList, Checksum};
+            Error -> Error
+        end,
+    {reply, Result, File};
 handle_call({pread_iolists, PosL}, _From, File) ->
-    update_read_timestamp(),
-    LocNums1 = [{Pos, 4} || Pos <- PosL],
-    DataSizes = read_multi_raw_iolists_int(File, LocNums1),
-    MapFun = fun({LenIoList, NextPos}) ->
-        case iolist_to_binary(LenIoList) of
-            % a checksum-prefixed term
-            <<1:1/integer, Len:31/integer>> -> {NextPos, Len + 16};
-            <<0:1/integer, Len:31/integer>> -> {NextPos, Len}
-        end
-    end,
-    LocNums2 = lists:map(MapFun, DataSizes),
-    Resps = read_multi_raw_iolists_int(File, LocNums2),
-    ZipFun = fun({LenIoList, _}, {FullIoList, _}) ->
-        case iolist_to_binary(LenIoList) of
-            <<1:1/integer, _:31/integer>> -> extract_checksum(FullIoList);
-            <<0:1/integer, _:31/integer>> -> {FullIoList, <<>>}
-        end
-    end,
-    Extracted = lists:zipwith(ZipFun, DataSizes, Resps),
-    {reply, {ok, Extracted}, File};
-handle_call(bytes, _From, #file{fd = Fd} = File) ->
-    {reply, file:position(Fd, eof), File};
+    {reply, pread(File, PosL), File};
+handle_call(bytes, _From, #file{} = File) ->
+    {reply, eof(File), File};
 handle_call({set_db_pid, Pid}, _From, #file{db_monitor = OldRef} = File) ->
     case is_reference(OldRef) of
         true -> demonitor(OldRef, [flush]);
@@ -539,22 +569,18 @@ handle_call({truncate, Pos}, _From, #file{fd = Fd} = File) ->
         Error ->
             {reply, Error, File}
     end;
-handle_call({append_bins, Bins}, _From, #file{fd = Fd, eof = Pos} = File) ->
-    {BlockResps, FinalPos} = lists:mapfoldl(
-        fun(Bin, PosAcc) ->
-            Blocks = make_blocks(PosAcc rem ?SIZE_BLOCK, Bin),
-            Size = iolist_size(Blocks),
-            {{Blocks, {PosAcc, Size}}, PosAcc + Size}
-        end,
-        Pos,
-        Bins
-    ),
-    {AllBlocks, Resps} = lists:unzip(BlockResps),
-    case file:write(Fd, AllBlocks) of
-        ok ->
-            {reply, {ok, Resps}, File#file{eof = FinalPos}};
-        Error ->
-            {reply, Error, reset_eof(File)}
+handle_call({append_bin, Bin}, _From, #file{} = File) ->
+    % Compatibility clause. Remove after upgrading to next release after 3.5.0
+    % Attachment streams may be opened from remote nodes during the upgrade on
+    % a mixed cluster
+    case append_bins(File, [Bin]) of
+        {{ok, [{Pos, Len}]}, File1} -> {reply, {ok, Pos, Len}, File1};
+        {Error, File1} -> {reply, Error, File1}
+    end;
+handle_call({append_bins, Bins}, _From, #file{} = File) ->
+    case append_bins(File, Bins) of
+        {{ok, Resps}, File1} -> {reply, {ok, Resps}, File1};
+        {Error, File1} -> {reply, Error, File1}
     end;
 handle_call({write_header, Bin}, _From, #file{fd = Fd, eof = Pos} = File) ->
     BinSize = byte_size(Bin),
@@ -595,9 +621,54 @@ format_status(_Opt, [PDict, #file{} = File]) ->
     {_Fd, FilePath} = couch_util:get_value(couch_file_fd, PDict),
     [{data, [{"State", File}, {"InitialFilePath", FilePath}]}].
 
+eof(#file{fd = Fd}) ->
+    file:position(Fd, eof).
+
+append_bins(#file{fd = Fd, eof = Pos} = File, Bins) ->
+    {BlockResps, FinalPos} = lists:mapfoldl(
+        fun(Bin, PosAcc) ->
+            Blocks = make_blocks(PosAcc rem ?SIZE_BLOCK, Bin),
+            Size = iolist_size(Blocks),
+            {{Blocks, {PosAcc, Size}}, PosAcc + Size}
+        end,
+        Pos,
+        Bins
+    ),
+    {AllBlocks, Resps} = lists:unzip(BlockResps),
+    case file:write(Fd, AllBlocks) of
+        ok -> {{ok, Resps}, File#file{eof = FinalPos}};
+        Error -> {Error, reset_eof(File)}
+    end.
+
+pread(#file{} = File, PosL) ->
+    LocNums1 = [{Pos, 4} || Pos <- PosL],
+    DataSizes = read_multi_raw_iolists_int(File, LocNums1),
+    MapFun = fun({LenIoList, NextPos}) ->
+        case iolist_to_binary(LenIoList) of
+            % a checksum-prefixed term
+            <<1:1/integer, Len:31/integer>> -> {NextPos, Len + 16};
+            <<0:1/integer, Len:31/integer>> -> {NextPos, Len}
+        end
+    end,
+    LocNums2 = lists:map(MapFun, DataSizes),
+    Resps = read_multi_raw_iolists_int(File, LocNums2),
+    ZipFun = fun({LenIoList, _}, {FullIoList, _}) ->
+        case iolist_to_binary(LenIoList) of
+            <<1:1/integer, _:31/integer>> -> extract_checksum(FullIoList);
+            <<0:1/integer, _:31/integer>> -> {FullIoList, <<>>}
+        end
+    end,
+    Extracted = lists:zipwith(ZipFun, DataSizes, Resps),
+    {ok, Extracted}.
+
 fsync(Fd) ->
     T0 = erlang:monotonic_time(),
-    Res = file:sync(Fd),
+    % We do not rely on mtime/atime for our safety/consitency so we can use
+    % fdatasync. As of version 25 OTP will use:
+    %  - On Linux/BSDs: fdatasync()
+    %  - On Window: FlushFileBuffers() i.e. the same as for file:sync/1
+    %  - On MacOS: fcntl(fd,F_FULLFSYNC/F_BARRIERFSYNC)
+    Res = file:datasync(Fd),
     T1 = erlang:monotonic_time(),
     % Since histograms can consume floating point values we can measure in
     % nanoseconds, then turn it into floating point milliseconds
@@ -688,35 +759,45 @@ find_newest_header(Fd, [{Location, Size} | LocationSizes]) ->
             find_newest_header(Fd, LocationSizes)
     end.
 
-read_multi_raw_iolists_int(#file{fd = Fd} = File, PosLens) ->
+read_multi_raw_iolists_int(#file{fd = Fd, eof = Eof} = File, PosLens) ->
     MapFun = fun({Pos, Len}) -> get_pread_locnum(File, Pos, Len) end,
     LocNums = lists:map(MapFun, PosLens),
-    {ok, Bins} = file:pread(Fd, LocNums),
     ZipFun = fun({Pos, TotalBytes}, Bin) ->
-        <<RawBin:TotalBytes/binary>> = Bin,
-        {remove_block_prefixes(Pos rem ?SIZE_BLOCK, RawBin), Pos + TotalBytes}
+        case is_binary(Bin) andalso byte_size(Bin) == TotalBytes of
+            true ->
+                {remove_block_prefixes(Pos rem ?SIZE_BLOCK, Bin), Pos + TotalBytes};
+            false ->
+                couch_stats:increment_counter([pread, exceed_eof]),
+                {ok, CurEof} = file:position(File#file.fd, eof),
+                Filepath = File#file.filepath,
+                throw_stop({read_beyond_eof, Filepath, Pos, TotalBytes, Eof, CurEof}, File)
+        end
     end,
-    lists:zipwith(ZipFun, LocNums, Bins).
+    case file:pread(Fd, LocNums) of
+        {ok, Bins} ->
+            lists:zipwith(ZipFun, LocNums, Bins);
+        {error, Error} ->
+            Filepath = File#file.filepath,
+            throw_stop({pread, Filepath, Error, hd(LocNums)}, File)
+    end.
 
-get_pread_locnum(#file{} = File, Pos, Len) ->
-    #file{eof = Eof, pread_limit = PreadLimit} = File,
+get_pread_locnum(#file{eof = Eof} = File, Pos, Len) ->
     BlockOffset = Pos rem ?SIZE_BLOCK,
     TotalBytes = calculate_total_read_len(BlockOffset, Len),
     case Pos + TotalBytes of
         Size when Size > Eof ->
             couch_stats:increment_counter([pread, exceed_eof]),
-            {_Fd, Filepath} = get(couch_file_fd),
-            ErrEof = {error, {read_beyond_eof, Filepath, Pos, Eof}},
-            throw({stop, ErrEof, ErrEof, File});
-        Size when Size > PreadLimit ->
-            couch_stats:increment_counter([pread, exceed_limit]),
-            {_Fd, Filepath} = get(couch_file_fd),
-            ErrPread = {error, {exceed_pread_limit, Filepath, PreadLimit}},
-            throw({stop, ErrPread, ErrPread, File});
+            {ok, CurEof} = file:position(File#file.fd, eof),
+            Filepath = File#file.filepath,
+            throw_stop({read_beyond_eof, Filepath, Pos, TotalBytes, Eof, CurEof}, File);
         _ ->
             {Pos, TotalBytes}
     end.
 
+throw_stop(Error, #file{} = File) ->
+    % This follows the gen_server reply via a throw pattern
+    throw({stop, {error, Error}, {error, Error}, File}).
+
 -spec extract_checksum(iolist()) -> {iolist(), binary()}.
 extract_checksum(FullIoList) ->
     {ChecksumList, IoList} = split_iolist(FullIoList, 16, []),
@@ -855,15 +936,6 @@ is_idle(#file{is_sys = false}) ->
 process_info(Pid) ->
     couch_util:process_dict_get(Pid, couch_file_fd).
 
-update_read_timestamp() ->
-    put(read_timestamp, os:timestamp()).
-
-get_pread_limit() ->
-    case config:get_integer("couchdb", "max_pread_size", 0) of
-        N when N > 0 -> N;
-        _ -> infinity
-    end.
-
 %% in event of a partially successful write.
 reset_eof(#file{} = File) ->
     {ok, Eof} = file:position(File#file.fd, eof),
@@ -887,6 +959,50 @@ generate_xxhash_checksums() ->
     Default = ?WRITE_XXHASH_CHECKSUMS_DEFAULT,
     config:get_boolean("couchdb", "write_xxhash_checksums", Default).
 
+% couch_cfile handling
+%
+
+get_cfile(Pid) when is_pid(Pid) ->
+    % Pids could be remote when processing attachments and is_process_alive/1
+    % will throw an error then, so ensure a fallback for non-local processes
+    PidAliveAndLocal = node(Pid) =:= node() andalso is_process_alive(Pid),
+    case {PidAliveAndLocal, get(?CFILE_HANDLE)} of
+        {false, _} ->
+            erase(?CFILE_HANDLE),
+            undefined;
+        {true, {Pid, #file{} = CFile}} ->
+            CFile;
+        {true, _} ->
+            % Maybe use an ets table as this is still a signal send/recv
+            case couch_util:process_dict_get(Pid, ?CFILE_HANDLE) of
+                #file{} = CFile ->
+                    put(?CFILE_HANDLE, {Pid, CFile}),
+                    CFile;
+                undefined ->
+                    undefined
+            end
+    end.
+
+dup(#file{fd = Fd} = File) ->
+    case config:get_boolean("couchdb", "use_cfile", ?USE_CFILE_DEFAULT) of
+        true ->
+            case couch_cfile:dup(Fd) of
+                {ok, CFd} ->
+                    % Successfully opened a couch_cfile handle, close
+                    % the original one to free the fd
+                    ok = file:close(Fd),
+                    CFile = File#file{fd = CFd},
+                    put(couch_file_fd, {CFd, CFile#file.filepath}),
+                    % Use an effective infinity for eof max limit for now
+                    put(?CFILE_HANDLE, CFile#file{eof = 1 bsl 60}),
+                    CFile;
+                {error, _Error} ->
+                    File
+            end;
+        false ->
+            File
+    end.
+
 -ifdef(TEST).
 -include_lib("couch/include/couch_eunit.hrl").
 
