@@ -109,14 +109,19 @@ default_authentication_handler(Req, AuthModule) ->
             case AuthModule:get_user_creds(Req, User) of
                 nil ->
                     throw({unauthorized, <<"Name or password is incorrect.">>});
-                {ok, UserProps, _AuthCtx} ->
+                {ok, UserProps, AuthCtx} ->
                     reject_if_totp(UserProps),
                     UserName = ?l2b(User),
                     Password = ?l2b(Pass),
                     case authenticate(Req, AuthModule, UserName, Password, UserProps) of
                         true ->
                             couch_password_hasher:maybe_upgrade_password_hash(
-                                AuthModule, UserName, Password, UserProps
+                                Req,
+                                UserName,
+                                Password,
+                                UserProps,
+                                AuthModule,
+                                AuthCtx
                             ),
                             Req#httpd{
                                 user_ctx = #user_ctx{
@@ -497,7 +502,7 @@ handle_session_req(#httpd{method = 'POST', mochi_req = MochiReq} = Req, AuthModu
     UserName = ?l2b(extract_username(Form)),
     Password = ?l2b(couch_util:get_value("password", Form, "")),
     couch_log:debug("Attempt Login: ~s", [UserName]),
-    {ok, UserProps, _AuthCtx} =
+    {ok, UserProps, AuthCtx} =
         case AuthModule:get_user_creds(Req, UserName) of
             nil -> {ok, [], nil};
             Result -> Result
@@ -506,7 +511,7 @@ handle_session_req(#httpd{method = 'POST', mochi_req = MochiReq} = Req, AuthModu
         true ->
             verify_totp(UserProps, Form),
             couch_password_hasher:maybe_upgrade_password_hash(
-                AuthModule, UserName, Password, UserProps
+                Req, UserName, Password, UserProps, AuthModule, AuthCtx
             ),
             % setup the session cookie
             Secret = ?l2b(ensure_cookie_auth_secret()),
@@ -653,7 +658,10 @@ authenticate_int(Pass, UserSalt, UserProps) ->
             <<"simple">> ->
                 authenticate_int_simple(Pass, UserSalt, UserProps);
             <<"pbkdf2">> ->
-                authenticate_int_pbkdf2(Pass, UserSalt, UserProps)
+                authenticate_int_pbkdf2(Pass, UserSalt, UserProps);
+            <<"simple+pbkdf2">> ->
+                LegacyHash = couch_passwords:simple(Pass, UserSalt),
+                authenticate_int_pbkdf2(LegacyHash, UserSalt, UserProps)
         end,
     couch_passwords:verify(PasswordHash, ExpectedHash).
 
@@ -823,3 +831,41 @@ lockout_warning(#httpd{mochi_req = Req}, User) ->
         "~p: Authentication rejected for locked-out user ~s from ~s",
         [?MODULE, User, Peer]
     ).
+
+-ifdef(TEST).
+-include_lib("couch/include/couch_eunit.hrl").
+
+simple_pbkdf2_test() ->
+    Password = <<"0123456789">>,
+    Salt = couch_uuids:random(),
+    PasswordSha = couch_passwords:simple(Password, Salt),
+    ?assert(
+        authenticate_int(
+            Password,
+            Salt,
+            [
+                {<<"password_scheme">>, <<"simple">>},
+                {<<"salt">>, Salt},
+                {<<"password_sha">>, PasswordSha}
+            ]
+        )
+    ),
+
+    Iterations = 5,
+    DerivedKey = couch_passwords:pbkdf2(sha256, PasswordSha, Salt, Iterations),
+
+    ?assert(
+        authenticate_int(
+            Password,
+            Salt,
+            [
+                {<<"password_scheme">>, <<"simple+pbkdf2">>},
+                {<<"salt">>, Salt},
+                {<<"pbkdf2_prf">>, <<"sha256">>},
+                {<<"iterations">>, Iterations},
+                {<<"derived_key">>, DerivedKey}
+            ]
+        )
+    ).
+
+-endif.
