@@ -39,15 +39,12 @@
 % to help simplify your view code.
 -module(couch_native_process).
 -behaviour(gen_server).
--vsn(1).
 
 -export([
     start_link/0,
     init/1,
-    terminate/2,
     handle_call/3,
     handle_cast/2,
-    code_change/3,
     handle_info/2
 ]).
 -export([set_timeout/2, prompt/2]).
@@ -129,8 +126,6 @@ handle_info({'EXIT', _, normal}, State) ->
     {noreply, State, State#evstate.idle};
 handle_info({'EXIT', _, Reason}, State) ->
     {stop, Reason, State}.
-terminate(_Reason, _State) -> ok.
-code_change(_OldVersion, State, _Extra) -> {ok, State}.
 
 run(#evstate{list_pid = Pid} = State, [<<"list_row">>, Row]) when is_pid(Pid) ->
     Pid ! {self(), list_row, Row},
@@ -392,7 +387,7 @@ makefun(State, Source) ->
     BindFuns = bindings(State, Sig),
     {Sig, makefun(State, Source, BindFuns)}.
 makefun(State, Source, {DDoc}) ->
-    Sig = couch_hash:md5_hash(lists:flatten([Source, term_to_binary(DDoc)])),
+    Sig = couch_hash:md5_hash(lists:flatten([Source, ?term_to_bin(DDoc)])),
     BindFuns = bindings(State, Sig, {DDoc}),
     {Sig, makefun(State, Source, BindFuns)};
 makefun(_State, Source, BindFuns) when is_list(BindFuns) ->
