@@ -12,12 +12,10 @@
 
 -module(couch_os_process).
 -behaviour(gen_server).
--vsn(1).
 
--export([start_link/1, start_link/2, start_link/3, stop/1]).
--export([set_timeout/2, prompt/2, killer/1]).
--export([send/2, writeline/2, readline/1, writejson/2, readjson/1]).
--export([init/1, terminate/2, handle_call/3, handle_cast/2, handle_info/2, code_change/3]).
+-export([start_link/1, stop/1]).
+-export([set_timeout/2, prompt/2]).
+-export([init/1, terminate/2, handle_call/3, handle_cast/2, handle_info/2]).
 
 -include_lib("couch/include/couch_db.hrl").
 
@@ -26,18 +24,13 @@
 -record(os_proc, {
     command,
     port,
-    writer,
-    reader,
     timeout = 5000,
-    idle
+    idle,
+    log_level
 }).
 
 start_link(Command) ->
-    start_link(Command, []).
-start_link(Command, Options) ->
-    start_link(Command, Options, ?PORT_OPTIONS).
-start_link(Command, Options, PortOptions) ->
-    gen_server:start_link(couch_os_process, [Command, Options, PortOptions], []).
+    gen_server:start_link(?MODULE, [Command], []).
 
 stop(Pid) ->
     gen_server:cast(Pid, stop).
@@ -46,10 +39,6 @@ stop(Pid) ->
 set_timeout(Pid, TimeOut) when is_integer(TimeOut) ->
     ok = gen_server:call(Pid, {set_timeout, TimeOut}, infinity).
 
-% Used by couch_event_os_process.erl
-send(Pid, Data) ->
-    gen_server:cast(Pid, {send, Data}).
-
 prompt(Pid, Data) ->
     case ioq:call(Pid, {prompt, Data}, erlang:get(io_priority)) of
         {ok, Result} ->
@@ -59,16 +48,11 @@ prompt(Pid, Data) ->
             throw(Error)
     end.
 
-% Utility functions for reading and writing
-% in custom functions
-writeline(OsProc, Data) when is_record(OsProc, os_proc) ->
-    Res = port_command(OsProc#os_proc.port, [Data, $\n]),
-    couch_io_logger:log_output(Data),
-    Res.
+% Utility functions for reading lines and parsing json
+%
 
 readline(#os_proc{} = OsProc) ->
     Res = readline(OsProc, []),
-    couch_io_logger:log_input(Res),
     Res.
 readline(#os_proc{port = Port} = OsProc, Acc) ->
     receive
@@ -89,21 +73,13 @@ readline(#os_proc{port = Port} = OsProc, Acc) ->
             throw({os_process_error, Err})
     after OsProc#os_proc.timeout ->
         catch port_close(Port),
+        log(OsProc, "OS Process ~p Timed out :: ~p msec", [Port, OsProc#os_proc.timeout]),
         throw({os_process_error, "OS process timed out."})
     end.
 
-% Standard JSON functions
-writejson(OsProc, Data) when is_record(OsProc, os_proc) ->
-    JsonData = ?JSON_ENCODE(Data),
-    couch_log:debug(
-        "OS Process ~p Input  :: ~s",
-        [OsProc#os_proc.port, JsonData]
-    ),
-    true = writeline(OsProc, JsonData).
-
 readjson(OsProc) when is_record(OsProc, os_proc) ->
     Line = iolist_to_binary(readline(OsProc)),
-    couch_log:debug("OS Process ~p Output :: ~s", [OsProc#os_proc.port, Line]),
+    log(OsProc, "OS Process ~p Output :: ~s", [OsProc#os_proc.port, Line]),
     try
         % Don't actually parse the whole JSON. Just try to see if it's
         % a command or a doc map/reduce/filter/show/list/update output.
@@ -153,81 +129,67 @@ pick_command1(_) ->
     throw(abort).
 
 % gen_server API
-init([Command, Options, PortOptions]) ->
-    couch_io_logger:start(os:getenv("COUCHDB_IO_LOG_DIR")),
-    PrivDir = couch_util:priv_dir(),
-    Spawnkiller = "\"" ++ filename:join(PrivDir, "couchspawnkillable") ++ "\"",
+init([Command]) ->
     V = config:get("query_server_config", "os_process_idle_limit", "300"),
     IdleLimit = list_to_integer(V) * 1000,
-    BaseProc = #os_proc{
+    LogLevel = log_level(os:getenv("COUCHDB_IO_LOG_LEVEL")),
+    T0 = erlang:monotonic_time(),
+    Port = open_port({spawn, Command}, ?PORT_OPTIONS),
+    {os_pid, OsPid} = erlang:port_info(Port, os_pid),
+    OsProc = #os_proc{
         command = Command,
-        port = open_port({spawn, Spawnkiller ++ " " ++ Command}, PortOptions),
-        writer = fun ?MODULE:writejson/2,
-        reader = fun ?MODULE:readjson/1,
-        idle = IdleLimit
+        port = Port,
+        idle = IdleLimit,
+        log_level = LogLevel
     },
-    KillCmd = iolist_to_binary(readline(BaseProc)),
+    T1 = erlang:monotonic_time(),
+    DtUSec = erlang:convert_time_unit(T1 - T0, native, microsecond),
+    bump_time_stat(spawn_proc, DtUSec),
     Pid = self(),
-    couch_log:debug("OS Process Start :: ~p", [BaseProc#os_proc.port]),
+    [CmdLog | _] = string:split(Command, " "),
+    CmdLog1 = filename:basename(CmdLog),
+    log(OsProc, "OS Process pid:~p port:~p Started :: ~p", [OsPid, Port, CmdLog1]),
+    couch_stats:increment_counter([couchdb, query_server, process_starts]),
     spawn(fun() ->
         % this ensure the real os process is killed when this process dies.
         erlang:monitor(process, Pid),
-        killer(?b2l(KillCmd))
+        killer(OsPid)
     end),
-    OsProc =
-        lists:foldl(
-            fun(Opt, Proc) ->
-                case Opt of
-                    {writer, Writer} when is_function(Writer) ->
-                        Proc#os_proc{writer = Writer};
-                    {reader, Reader} when is_function(Reader) ->
-                        Proc#os_proc{reader = Reader};
-                    {timeout, TimeOut} when is_integer(TimeOut) ->
-                        Proc#os_proc{timeout = TimeOut}
-                end
-            end,
-            BaseProc,
-            Options
-        ),
     {ok, OsProc, IdleLimit}.
 
-terminate(Reason, #os_proc{port = Port}) ->
+terminate(Reason, #os_proc{port = Port} = OsProc) ->
     catch port_close(Port),
-    case Reason of
-        normal ->
-            couch_io_logger:stop_noerror();
-        Error ->
-            couch_io_logger:stop_error(Error)
-    end,
+    log(OsProc, "OS Process ~p Terminated :: ~p", [Port, Reason]),
     ok.
 
 handle_call({set_timeout, TimeOut}, _From, #os_proc{idle = Idle} = OsProc) ->
     {reply, ok, OsProc#os_proc{timeout = TimeOut}, Idle};
 handle_call({prompt, Data}, _From, #os_proc{idle = Idle} = OsProc) ->
-    #os_proc{writer = Writer, reader = Reader} = OsProc,
     try
-        Writer(OsProc, Data),
-        {reply, {ok, Reader(OsProc)}, OsProc, Idle}
+        couch_stats:increment_counter([couchdb, query_server, process_prompts]),
+        JsonData = ?JSON_ENCODE(Data),
+        log(OsProc, "OS Process ~p Input :: ~s", [OsProc#os_proc.port, JsonData]),
+        T0 = erlang:monotonic_time(),
+        true = port_command(OsProc#os_proc.port, [JsonData, $\n]),
+        Response = readjson(OsProc),
+        T1 = erlang:monotonic_time(),
+        DtUSec = erlang:convert_time_unit(T1 - T0, native, microsecond),
+        bump_cmd_time_stat(Data, DtUSec),
+        {reply, {ok, Response}, OsProc, Idle}
     catch
         throw:{error, OsError} ->
+            couch_stats:increment_counter([couchdb, query_server, process_errors]),
             {reply, OsError, OsProc, Idle};
         throw:{fatal, OsError} ->
+            couch_stats:increment_counter([couchdb, query_server, process_errors]),
             {stop, normal, OsError, OsProc};
         throw:OtherError ->
+            couch_stats:increment_counter([couchdb, query_server, process_errors]),
             {stop, normal, OtherError, OsProc}
     after
         garbage_collect()
     end.
 
-handle_cast({send, Data}, #os_proc{writer = Writer, idle = Idle} = OsProc) ->
-    try
-        Writer(OsProc, Data),
-        {noreply, OsProc, Idle}
-    catch
-        throw:OsError ->
-            couch_log:error("Failed sending data: ~p -> ~p", [Data, OsError]),
-            {stop, normal, OsProc}
-    end;
 handle_cast(garbage_collect, #os_proc{idle = Idle} = OsProc) ->
     erlang:garbage_collect(),
     {noreply, OsProc, Idle};
@@ -243,32 +205,71 @@ handle_info(timeout, #os_proc{idle = Idle} = OsProc) ->
     {noreply, OsProc, Idle};
 handle_info({Port, {exit_status, 0}}, #os_proc{port = Port} = OsProc) ->
     couch_log:info("OS Process terminated normally", []),
+    couch_stats:increment_counter([couchdb, query_server, process_exits]),
     {stop, normal, OsProc};
 handle_info({Port, {exit_status, Status}}, #os_proc{port = Port} = OsProc) ->
     couch_log:error("OS Process died with status: ~p", [Status]),
+    couch_stats:increment_counter([couchdb, query_server, process_error_exits]),
     {stop, {exit_status, Status}, OsProc};
 handle_info(Msg, #os_proc{idle = Idle} = OsProc) ->
-    couch_log:debug("OS Proc: Unknown info: ~p", [Msg]),
+    log(OsProc, "OS Process ~p Unknown info :: ~p", [OsProc#os_proc.port, Msg]),
     {noreply, OsProc, Idle}.
 
-code_change(_, {os_proc, Cmd, Port, W, R, Timeout}, _) ->
-    V = config:get("query_server_config", "os_process_idle_limit", "300"),
-    State = #os_proc{
-        command = Cmd,
-        port = Port,
-        writer = W,
-        reader = R,
-        timeout = Timeout,
-        idle = list_to_integer(V) * 1000
-    },
-    {ok, State};
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
+kill_command(OsPid) ->
+    OsPid1 = integer_to_list(OsPid),
+    case os:type() of
+        {win32, _} -> "taskkill /f /pid " ++ OsPid1;
+        {_, _} -> "kill -9 " ++ OsPid1
+    end.
 
-killer(KillCmd) ->
+killer(OsPid) when is_integer(OsPid), OsPid > 0 ->
     receive
         _ ->
-            os:cmd(KillCmd)
+            os:cmd(kill_command(OsPid))
     after 1000 ->
-        ?MODULE:killer(KillCmd)
+        killer(OsPid)
     end.
+
+bump_cmd_time_stat(Cmd, USec) when is_list(Cmd), is_integer(USec) ->
+    case Cmd of
+        [<<"map_doc">> | _] ->
+            bump_time_stat(map, USec);
+        [<<"reduce">> | _] ->
+            bump_time_stat(reduce, USec);
+        [<<"rereduce">> | _] ->
+            bump_time_stat(reduce, USec);
+        [<<"reset">> | _] ->
+            bump_time_stat(reset, USec);
+        [<<"add_fun">> | _] ->
+            bump_time_stat(add_fun, USec);
+        [<<"ddoc">>, <<"new">> | _] ->
+            bump_time_stat(ddoc_new, USec);
+        [<<"ddoc">>, _, [<<"validate_doc_update">> | _] | _] ->
+            bump_time_stat(ddoc_vdu, USec);
+        [<<"ddoc">>, _, [<<"filters">> | _] | _] ->
+            bump_time_stat(ddoc_filter, USec);
+        [<<"ddoc">> | _] ->
+            bump_time_stat(ddoc_other, USec);
+        _ ->
+            bump_time_stat(other, USec)
+    end.
+
+bump_time_stat(Stat, USec) when is_atom(Stat), is_integer(USec) ->
+    couch_stats:increment_counter([couchdb, query_server, calls, Stat]),
+    couch_stats:increment_counter([couchdb, query_server, time, Stat], USec).
+
+log_level("debug") ->
+    debug;
+log_level("info") ->
+    info;
+log_level("notice") ->
+    notice;
+log_level("warning") ->
+    warning;
+log_level("error") ->
+    error;
+log_level(_) ->
+    debug.
+
+log(#os_proc{log_level = LogLevel}, Fmt, Args) ->
+    couch_log:LogLevel(Fmt, Args).
