@@ -13,13 +13,12 @@
 -include_lib("couch/include/couch_db.hrl").
 
 -behaviour(gen_server).
--vsn(3).
 -behaviour(config_listener).
 
 -export([start/0, stop/0]).
 -export([new/0, random/0]).
 
--export([init/1, terminate/2, code_change/3]).
+-export([init/1]).
 -export([handle_call/3, handle_cast/2, handle_info/2]).
 
 % config_listener api
@@ -43,9 +42,6 @@ init([]) ->
     ok = config:listen_for_changes(?MODULE, nil),
     {ok, state()}.
 
-terminate(_Reason, _State) ->
-    ok.
-
 handle_call(create, _From, random) ->
     {reply, random(), random};
 handle_call(create, _From, {utc_random, ClockSeq}) ->
@@ -77,9 +73,6 @@ handle_info(restart_config_listener, State) ->
 handle_info(_Info, State) ->
     {noreply, State}.
 
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 handle_config_change("uuids", _, _, _, _) ->
     {ok, gen_server:cast(?MODULE, change)};
 handle_config_change(_, _, _, _, _) ->
@@ -95,7 +88,7 @@ new_prefix() ->
     couch_util:to_hex((crypto:strong_rand_bytes(13))).
 
 inc() ->
-    couch_rand:uniform(16#ffd).
+    rand:uniform(16#ffd).
 
 state() ->
     AlgoStr = config:get("uuids", "algorithm", "sequential"),
