@@ -20,9 +20,11 @@
 
 setup() ->
     {ok, Fd} = couch_file:open(?tempfile(), [create, overwrite]),
+    meck:new(file, [passthrough, unstick]),
     Fd.
 
 teardown(Fd) ->
+    meck:unload(file),
     case is_process_alive(Fd) of
         true -> ok = couch_file:close(Fd);
         false -> ok
@@ -65,12 +67,68 @@ should_close_file_properly() ->
 should_create_empty_new_files(Fd) ->
     ?_assertMatch({ok, 0}, couch_file:bytes(Fd)).
 
+cfile_setup() ->
+    test_util:start_couch().
+
+cfile_teardown(Ctx) ->
+    erase(io_priority),
+    config:delete("couchdb", "use_cfile", false),
+    config:delete("couchdb", "cfile_skip_ioq", false),
+    config:delete("ioq.bypass", "read", false),
+    test_util:stop_couch(Ctx).
+
+cfile_enable_disable_test_() ->
+    {
+        foreach,
+        fun cfile_setup/0,
+        fun cfile_teardown/1,
+        [
+            ?TDEF_FE(t_cfile_default),
+            ?TDEF_FE(t_cfile_enabled),
+            ?TDEF_FE(t_cfile_disabled),
+            ?TDEF_FE(t_cfile_with_ioq_bypass),
+            ?TDEF_FE(t_cfile_without_ioq_bypass)
+        ]
+    }.
+
+t_cfile_default(_) ->
+    t_can_open_read_and_write().
+
+t_cfile_enabled(_) ->
+    % This is the default, but we'll just test when we
+    % explicitly set to "true" here
+    config:set("couchdb", "use_cfile", "true", false),
+    t_can_open_read_and_write().
+
+t_cfile_disabled(_) ->
+    config:set("couchdb", "use_cfile", "false", false),
+    t_can_open_read_and_write().
+
+t_cfile_with_ioq_bypass(_) ->
+    config:set("couchdb", "use_cfile", "true", false),
+    config:set("couchdb", "cfile_skip_ioq", "true", false),
+    config:set("ioq.bypass", "read", "true", false),
+    t_can_open_read_and_write().
+
+t_cfile_without_ioq_bypass(_) ->
+    config:set("couchdb", "use_cfile", "true", false),
+    config:set("couchdb", "cfile_skip_ioq", "false", false),
+    config:set("ioq.bypass", "read", "true", false),
+    t_can_open_read_and_write().
+
+t_can_open_read_and_write() ->
+    {ok, Fd} = couch_file:open(?tempfile(), [create, overwrite]),
+    ioq:set_io_priority({interactive, <<"somedb">>}),
+    ?assertMatch({ok, 0, _}, couch_file:append_term(Fd, foo)),
+    ?assertEqual({ok, foo}, couch_file:pread_term(Fd, 0)),
+    ok = couch_file:close(Fd).
+
 read_write_test_() ->
     {
         "Common file read/write tests",
         {
             setup,
-            fun() -> test_util:start_couch() end,
+            fun test_util:start_couch/0,
             fun test_util:stop_couch/1,
             {
                 foreach,
@@ -89,14 +147,17 @@ read_write_test_() ->
                     ?TDEF_FE(should_fsync_by_path),
                     ?TDEF_FE(should_update_fsync_stats),
                     ?TDEF_FE(should_not_read_beyond_eof),
+                    ?TDEF_FE(should_not_read_beyond_eof_when_externally_truncated),
+                    ?TDEF_FE(should_catch_pread_failure),
                     ?TDEF_FE(should_truncate),
                     ?TDEF_FE(should_set_db_pid),
-                    ?TDEF_FE(should_update_last_read_time),
                     ?TDEF_FE(should_open_read_only),
                     ?TDEF_FE(should_apply_overwrite_create_option),
                     ?TDEF_FE(should_error_on_creation_if_exists),
                     ?TDEF_FE(should_close_on_idle),
-                    ?TDEF_FE(should_crash_on_unexpected_cast)
+                    ?TDEF_FE(should_crash_on_unexpected_cast),
+                    ?TDEF_FE(should_handle_pread_iolist_upgrade_clause),
+                    ?TDEF_FE(should_handle_append_bin_upgrade_clause)
                 ]
             }
         }
@@ -174,7 +235,35 @@ should_not_read_beyond_eof(_) ->
     ok = file:pwrite(Io, Pos, <<0:1/integer, DoubleBin:31/integer>>),
     file:close(Io),
     unlink(Fd),
-    ?assertMatch({error, {read_beyond_eof, Filepath, _, _}}, couch_file:pread_binary(Fd, Pos)),
+    ?assertMatch(
+        {error, {read_beyond_eof, Filepath, _, _, _, _}}, couch_file:pread_binary(Fd, Pos)
+    ),
+    catch file:close(Fd).
+
+should_not_read_beyond_eof_when_externally_truncated(_) ->
+    {ok, Fd} = couch_file:open(?tempfile(), [create, overwrite]),
+    Bin = list_to_binary(lists:duplicate(100, 0)),
+    {ok, Pos, _Size} = couch_file:append_binary(Fd, Bin),
+    {_, Filepath} = couch_file:process_info(Fd),
+    %% corrupt db file by truncating it
+    {ok, Io} = file:open(Filepath, [read, write, binary]),
+    % 4 (len) + 1 byte
+    {ok, _} = file:position(Io, Pos + 5),
+    ok = file:truncate(Io),
+    file:close(Io),
+    unlink(Fd),
+    ?assertMatch(
+        {error, {read_beyond_eof, Filepath, _, _, _, _}}, couch_file:pread_binary(Fd, Pos)
+    ),
+    catch file:close(Fd).
+
+should_catch_pread_failure(_) ->
+    {ok, Fd} = couch_file:open(?tempfile(), [create, overwrite]),
+    {ok, Pos, _Size} = couch_file:append_binary(Fd, <<"x">>),
+    {_, Filepath} = couch_file:process_info(Fd),
+    meck:expect(file, pread, 2, {error, einval}),
+    unlink(Fd),
+    ?assertMatch({error, {pread, Filepath, einval, {0, _}}}, couch_file:pread_terms(Fd, [Pos])),
     catch file:close(Fd).
 
 should_truncate(Fd) ->
@@ -213,15 +302,6 @@ should_set_db_pid(Fd) ->
     ),
     ?assertNot(is_process_alive(Fd)).
 
-should_update_last_read_time(Fd) ->
-    {ok, Pos, _} = couch_file:append_term(Fd, foo),
-    ReadTs1 = couch_file:last_read(Fd),
-    ?assertMatch({_, _, _}, ReadTs1),
-    {ok, foo} = couch_file:pread_term(Fd, Pos),
-    ReadTs2 = couch_file:last_read(Fd),
-    ?assertMatch({_, _, _}, ReadTs2),
-    ?assert(ReadTs2 > ReadTs1).
-
 should_open_read_only(Fd) ->
     {_, Path} = couch_file:process_info(Fd),
     {ok, Pos, _} = couch_file:append_term(Fd, foo),
@@ -238,8 +318,10 @@ should_apply_overwrite_create_option(Fd) ->
     ?assertEqual(ok, couch_file:close(Fd)),
     {ok, Fd1} = couch_file:open(Path, [create, overwrite]),
     unlink(Fd1),
-    ExpectError = {error, {read_beyond_eof, Path, Pos, 0}},
-    ?assertEqual(ExpectError, couch_file:pread_term(Fd1, Pos)).
+    ?assertMatch(
+        {error, {read_beyond_eof, Path, Pos, _, _, _}},
+        couch_file:pread_term(Fd1, Pos)
+    ).
 
 should_error_on_creation_if_exists(Fd) ->
     {_, Path} = couch_file:process_info(Fd),
@@ -280,49 +362,44 @@ should_crash_on_unexpected_cast(Fd) ->
             ?assertEqual({invalid_cast, potato}, Reason)
     end.
 
-pread_limit_test_() ->
-    {
-        "Read limit tests",
-        {
-            setup,
-            fun() ->
-                Ctx = test_util:start_couch([ioq]),
-                config:set("couchdb", "max_pread_size", "50000", _Persist = false),
-                Ctx
-            end,
-            fun(Ctx) ->
-                config:delete("couchdb", "max_pread_size", _Persist = false),
-                test_util:stop_couch(Ctx)
-            end,
-            {
-                foreach,
-                fun setup/0,
-                fun teardown/1,
-                [
-                    ?TDEF_FE(should_increase_file_size_on_write),
-                    ?TDEF_FE(should_return_current_file_size_on_write),
-                    ?TDEF_FE(should_write_and_read_term),
-                    ?TDEF_FE(should_write_and_read_binary),
-                    ?TDEF_FE(should_not_read_more_than_pread_limit)
-                ]
-            }
-        }
-    }.
+% Remove this test when removing pread_iolist compatibility clause for online
+% upgrades from couch_file
+%
+should_handle_pread_iolist_upgrade_clause(Fd) ->
+    Bin = <<"bin">>,
+    {ok, Pos, _} = couch_file:append_binary(Fd, Bin),
+    ResList = gen_server:call(Fd, {pread_iolists, [Pos]}, infinity),
+    ?assertMatch({ok, [{_, _}]}, ResList),
+    {ok, [{IoList1, Checksum1}]} = ResList,
+    ?assertEqual(Bin, iolist_to_binary(IoList1)),
+    ?assertEqual(<<>>, Checksum1),
+    ResSingle = gen_server:call(Fd, {pread_iolist, Pos}, infinity),
+    ?assertMatch({ok, _, _}, ResSingle),
+    {ok, IoList2, Checksum2} = ResSingle,
+    ?assertEqual(Bin, iolist_to_binary(IoList2)),
+    ?assertEqual(<<>>, Checksum2).
 
-should_not_read_more_than_pread_limit(_) ->
-    {ok, Fd} = couch_file:open(?tempfile(), [create, overwrite]),
-    {_, Filepath} = couch_file:process_info(Fd),
-    BigBin = list_to_binary(lists:duplicate(100000, 0)),
-    {ok, Pos, _Size} = couch_file:append_binary(Fd, BigBin),
-    unlink(Fd),
-    Ref = monitor(process, Fd),
-    ExpectError = {error, {exceed_pread_limit, Filepath, 50000}},
-    ?assertEqual(ExpectError, couch_file:pread_binary(Fd, Pos)),
-    receive
-        {'DOWN', Ref, _, _, Reason} ->
-            ?assertEqual(ExpectError, Reason)
-    end,
-    catch file:close(Fd).
+% Remove this test when removing append_bin compatibility clause for online
+% upgrades from couch_file
+%
+should_handle_append_bin_upgrade_clause(Fd) ->
+    Bin = <<"bin">>,
+    Chunk = couch_file:assemble_file_chunk_and_checksum(Bin),
+    ResList = gen_server:call(Fd, {append_bins, [Chunk]}, infinity),
+    ?assertMatch({ok, [_]}, ResList),
+    {ok, [{Pos1, Len1}]} = ResList,
+    ?assertEqual({ok, Bin}, couch_file:pread_binary(Fd, Pos1)),
+    ?assert(is_integer(Len1)),
+    % size of binary + checksum
+    ?assert(Len1 > byte_size(Bin) + 16),
+    ResSingle = gen_server:call(Fd, {append_bin, Chunk}, infinity),
+    ?assertMatch({ok, _, _}, ResSingle),
+    {ok, Pos2, Len2} = ResSingle,
+    ?assert(is_integer(Len2)),
+    % size of binary + checksum
+    ?assert(Len2 > byte_size(Bin) + 16),
+    ?assertEqual(Pos2, Len1),
+    ?assertEqual({ok, Bin}, couch_file:pread_binary(Fd, Pos2)).
 
 header_test_() ->
     {
