@@ -16,7 +16,7 @@
 -compile(tuple_calls).
 
 -export([start_link/0, stop/0, loop/1, get_port/0, set_assert/1, check_last/0]).
--export([init/1, terminate/2, code_change/3]).
+-export([init/1]).
 -export([handle_call/3, handle_cast/2, handle_info/2]).
 
 -include_lib("couch/include/couch_eunit.hrl").
@@ -67,9 +67,6 @@ check_last() ->
 init(_) ->
     {ok, nil}.
 
-terminate(_Reason, _State) ->
-    ok.
-
 stop() ->
     mochiweb_http:stop(?SERVER).
 
@@ -109,6 +106,3 @@ handle_cast(Msg, State) ->
 handle_info(Msg, State) ->
     ?debugFmt("Ignoring info message: ~p", [Msg]),
     {noreply, State}.
-
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
