@@ -25,6 +25,8 @@
 -include_lib("couch/include/couch_db.hrl").
 -include_lib("couch_mrview/include/couch_mrview.hrl").
 
+-define(MAX_RANK, 100).
+
 -record(mracc, {
     db,
     meta_sent = false,
@@ -211,6 +213,14 @@ validate(Db, DDoc) ->
                     ok;
                 ({_RedName, <<"_approx_count_distinct", _/binary>>}) ->
                     ok;
+                ({_RedName, <<"_top_", N/binary>>}) ->
+                    ok = check_rank(N);
+                ({_RedName, <<"_bottom_", N/binary>>}) ->
+                    ok = check_rank(N);
+                ({_RedName, <<"_first", _/binary>>}) ->
+                    ok;
+                ({_RedName, <<"_last", _/binary>>}) ->
+                    ok;
                 ({_RedName, <<"_", _/binary>> = Bad}) ->
                     Msg = ["`", Bad, "` is not a supported reduce function."],
                     throw({invalid_design_doc, Msg});
@@ -253,24 +263,36 @@ validate(Db, DDoc) ->
             ok
     end.
 
+check_rank(<<N/binary>>) ->
+    try binary_to_integer(N) of
+        Val when Val >= 1 andalso Val =< ?MAX_RANK ->
+            ok;
+        _ ->
+            Msg = ["rank value must be between 1 and ", integer_to_list(?MAX_RANK)],
+            throw({invalid_design_doc, Msg})
+    catch
+        error:badarg ->
+            throw({invalid_design_doc, "invalid rank reducer"})
+    end.
+
 query_all_docs(Db, Args) ->
     query_all_docs(Db, Args, fun default_cb/2, []).
 
 query_all_docs(Db, Args, Callback, Acc) when is_list(Args) ->
-    query_all_docs(Db, to_mrargs(Args), Callback, Acc);
+    Args1 = couch_mrview_util:validate_all_docs_args(Db, to_mrargs(Args)),
+    query_all_docs(Db, Args1, Callback, Acc);
 query_all_docs(Db, Args0, Callback, Acc) ->
     Sig = couch_util:with_db(Db, fun(WDb) ->
         {ok, Info} = couch_db:get_db_info(WDb),
         couch_index_util:hexsig(couch_hash:md5_hash(?term_to_bin(Info)))
     end),
     Args1 = Args0#mrargs{view_type = map},
-    Args2 = couch_mrview_util:validate_all_docs_args(Db, Args1),
     {ok, Acc1} =
-        case Args2#mrargs.preflight_fun of
+        case Args1#mrargs.preflight_fun of
             PFFun when is_function(PFFun, 2) -> PFFun(Sig, Acc);
             _ -> {ok, Acc}
         end,
-    all_docs_fold(Db, Args2, Callback, Acc1).
+    all_docs_fold(Db, Args1, Callback, Acc1).
 
 query_view(Db, DDoc, VName) ->
     Args = #mrargs{extra = [{view_row_map, true}]},
