@@ -24,7 +24,7 @@ setup_all() ->
     TestCtx = test_util:start_couch([chttpd]),
     ok = application:start(couch_peruser),
     Hashed = couch_passwords:hash_admin_password(?ADMIN_PASSWORD),
-    ok = config:set("admins", ?ADMIN_USERNAME, ?b2l(Hashed), _Persist=false),
+    ok = config:set("admins", ?ADMIN_USERNAME, ?b2l(Hashed), _Persist = false),
     TestCtx.
 
 teardown_all(TestCtx) ->
@@ -52,18 +52,21 @@ teardown(TestAuthDb) ->
     set_config("cluster", "n", "3"),
     do_request(delete, get_cluster_base_url() ++ "/" ++ ?b2l(TestAuthDb)),
     do_request(delete, get_base_url() ++ "/" ++ ?b2l(TestAuthDb)),
-    lists:foreach(fun(DbName) ->
-        case binary:part(DbName, 0, 7) of
-            <<"userdb-">> -> delete_db(DbName);
-            _ -> ok
-        end
-    end, all_dbs()).
+    lists:foreach(
+        fun(DbName) ->
+            case binary:part(DbName, 0, 7) of
+                <<"userdb-">> -> delete_db(DbName);
+                _ -> ok
+            end
+        end,
+        all_dbs()
+    ).
 
 set_config(Section, Key, Value) ->
-    ok = config:set(Section, Key, Value, _Persist=false).
+    ok = config:set(Section, Key, Value, _Persist = false).
 
 delete_config(Section, Key) ->
-    ok = config:delete(Section, Key, _Persist=false).
+    ok = config:delete(Section, Key, _Persist = false).
 
 do_request(Method, Url) ->
     Headers = [{basic_auth, {?ADMIN_USERNAME, ?ADMIN_PASSWORD}}],
@@ -72,12 +75,14 @@ do_request(Method, Url) ->
 do_request(Method, Url, Body) ->
     Headers = [
         {basic_auth, {?ADMIN_USERNAME, ?ADMIN_PASSWORD}},
-        {"Content-Type", "application/json"}],
+        {"Content-Type", "application/json"}
+    ],
     {ok, _, _, _} = test_request:request(Method, Url, Headers, Body).
 
 do_anon_request(Method, Url, Body) ->
     Headers = [
-        {"Content-Type", "application/json"}],
+        {"Content-Type", "application/json"}
+    ],
     {ok, _, _, _} = test_request:request(Method, Url, Headers, Body).
 
 create_db(DbName) ->
@@ -87,22 +92,31 @@ delete_db(DbName) ->
     {ok, _, _, _} = do_request(delete, get_cluster_base_url() ++ "/" ++ ?b2l(DbName)).
 
 create_user(AuthDb, Name) ->
-    Body = "{\"name\":\"" ++ Name ++
-        "\",\"type\":\"user\",\"roles\":[],\"password\":\"secret\"}",
+    Body =
+        "{\"name\":\"" ++ Name ++
+            "\",\"type\":\"user\",\"roles\":[],\"password\":\"secret\"}",
     Url = lists:concat([
-        get_cluster_base_url(), "/", ?b2l(AuthDb), "/org.couchdb.user:", Name]),
+        get_cluster_base_url(), "/", ?b2l(AuthDb), "/org.couchdb.user:", Name
+    ]),
     {ok, 201, _, _} = do_request(put, Url, Body).
 
 create_anon_user(AuthDb, Name) ->
-    Body = "{\"name\":\"" ++ Name ++
-        "\",\"type\":\"user\",\"roles\":[],\"password\":\"secret\"}",
+    Body =
+        "{\"name\":\"" ++ Name ++
+            "\",\"type\":\"user\",\"roles\":[],\"password\":\"secret\"}",
     Url = lists:concat([
-        get_cluster_base_url(), "/", ?b2l(AuthDb), "/org.couchdb.user:", Name]),
+        get_cluster_base_url(), "/", ?b2l(AuthDb), "/org.couchdb.user:", Name
+    ]),
     {ok, 201, _, _} = do_anon_request(put, Url, Body).
 
 delete_user(AuthDb, Name) ->
-    Url = lists:concat([get_cluster_base_url(), "/", ?b2l(AuthDb),
-        "/org.couchdb.user:", Name]),
+    Url = lists:concat([
+        get_cluster_base_url(),
+        "/",
+        ?b2l(AuthDb),
+        "/org.couchdb.user:",
+        Name
+    ]),
     {ok, 200, _, Body} = do_request(get, Url),
     {DocProps} = jiffy:decode(Body),
     Rev = proplists:get_value(<<"_rev">>, DocProps),
@@ -110,7 +124,8 @@ delete_user(AuthDb, Name) ->
 
 get_security(DbName) ->
     Url = lists:concat([
-        get_cluster_base_url(), "/", ?b2l(DbName), "/_security"]),
+        get_cluster_base_url(), "/", ?b2l(DbName), "/_security"
+    ]),
     test_util:wait(fun() ->
         {ok, 200, _, Body} = do_request(get, Url),
         case jiffy:decode(Body) of
@@ -121,7 +136,8 @@ get_security(DbName) ->
 
 set_security(DbName, SecurityProperties) ->
     Url = lists:concat([
-        get_cluster_base_url(), "/", ?b2l(DbName), "/_security"]),
+        get_cluster_base_url(), "/", ?b2l(DbName), "/_security"
+    ]),
     Body = jiffy:encode({SecurityProperties}),
     {ok, 200, _, _} = do_request(put, Url, Body).
 
@@ -143,7 +159,6 @@ get_cluster_base_url() ->
     Port = integer_to_list(mochiweb_socket_server:get(chttpd, port)),
     "http://" ++ Addr ++ ":" ++ Port.
 
-
 should_create_user_db_with_default(TestAuthDb) ->
     ?_test(begin
         create_user(TestAuthDb, "foo"),
@@ -288,42 +303,42 @@ should_delete_user_db_with_custom_special_prefix(TestAuthDb) ->
     end).
 
 should_reflect_config_changes(TestAuthDb) ->
-    {timeout, 10000, ?_test(begin
-        User = "baz",
-        UserDbName = <<"userdb-62617a">>,
-        set_config("couch_peruser", "delete_dbs", "true"),
-        create_user(TestAuthDb, User),
-        wait_for_db_create(UserDbName),
-        AfterCreate1 = lists:member(UserDbName, all_dbs()),
-        delete_user(TestAuthDb, User),
-        timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
-        wait_for_db_delete(UserDbName),
-        AfterDelete1 = lists:member(UserDbName, all_dbs()),
-        create_user(TestAuthDb, User),
-        wait_for_db_create(UserDbName),
-        AfterCreate2 = lists:member(UserDbName, all_dbs()),
-        set_config("couch_peruser", "delete_dbs", "false"),
-        delete_user(TestAuthDb, User),
-        timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
-        AfterDelete2 = lists:member(UserDbName, all_dbs()),
-        create_user(TestAuthDb, User),
-        wait_for_db_create(UserDbName),
-        set_config("couch_peruser", "delete_dbs", "true"),
-        delete_user(TestAuthDb, User),
-        wait_for_db_delete(UserDbName),
-        AfterDelete3 = lists:member(UserDbName, all_dbs()),
-        set_config("couch_peruser", "enable", "false"),
-        create_user(TestAuthDb, User),
-        timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
-        AfterCreate3 = lists:member(UserDbName, all_dbs()),
-        ?assert(AfterCreate1),
-        ?assertNot(AfterDelete1),
-        ?assert(AfterCreate2),
-        ?assert(AfterDelete2),
-        ?assertNot(AfterDelete3),
-        ?assertNot(AfterCreate3)
-    end)}.
-
+    {timeout, 10000,
+        ?_test(begin
+            User = "baz",
+            UserDbName = <<"userdb-62617a">>,
+            set_config("couch_peruser", "delete_dbs", "true"),
+            create_user(TestAuthDb, User),
+            wait_for_db_create(UserDbName),
+            AfterCreate1 = lists:member(UserDbName, all_dbs()),
+            delete_user(TestAuthDb, User),
+            timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
+            wait_for_db_delete(UserDbName),
+            AfterDelete1 = lists:member(UserDbName, all_dbs()),
+            create_user(TestAuthDb, User),
+            wait_for_db_create(UserDbName),
+            AfterCreate2 = lists:member(UserDbName, all_dbs()),
+            set_config("couch_peruser", "delete_dbs", "false"),
+            delete_user(TestAuthDb, User),
+            timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
+            AfterDelete2 = lists:member(UserDbName, all_dbs()),
+            create_user(TestAuthDb, User),
+            wait_for_db_create(UserDbName),
+            set_config("couch_peruser", "delete_dbs", "true"),
+            delete_user(TestAuthDb, User),
+            wait_for_db_delete(UserDbName),
+            AfterDelete3 = lists:member(UserDbName, all_dbs()),
+            set_config("couch_peruser", "enable", "false"),
+            create_user(TestAuthDb, User),
+            timer:sleep(?WAIT_FOR_USER_DELETE_TIMEOUT),
+            AfterCreate3 = lists:member(UserDbName, all_dbs()),
+            ?assert(AfterCreate1),
+            ?assertNot(AfterDelete1),
+            ?assert(AfterCreate2),
+            ?assert(AfterDelete2),
+            ?assertNot(AfterDelete3),
+            ?assertNot(AfterCreate3)
+        end)}.
 
 should_add_user_to_db_admins(TestAuthDb) ->
     ?_test(begin
@@ -332,8 +347,9 @@ should_add_user_to_db_admins(TestAuthDb) ->
         create_user(TestAuthDb, User),
         wait_for_db_create(UserDbName),
         ?assertEqual(
-            {[{<<"names">>,[<<"qux">>]}]},
-            proplists:get_value(<<"admins">>, get_security(UserDbName)))
+            {[{<<"names">>, [<<"qux">>]}]},
+            proplists:get_value(<<"admins">>, get_security(UserDbName))
+        )
     end).
 
 should_add_user_to_db_members(TestAuthDb) ->
@@ -343,8 +359,9 @@ should_add_user_to_db_members(TestAuthDb) ->
         create_user(TestAuthDb, User),
         wait_for_db_create(UserDbName),
         ?assertEqual(
-            {[{<<"names">>,[<<"qux">>]}]},
-            proplists:get_value(<<"members">>, get_security(UserDbName)))
+            {[{<<"names">>, [<<"qux">>]}]},
+            proplists:get_value(<<"members">>, get_security(UserDbName))
+        )
     end).
 
 should_not_remove_existing_db_admins(TestAuthDb) ->
@@ -352,15 +369,17 @@ should_not_remove_existing_db_admins(TestAuthDb) ->
         User = "qux",
         UserDbName = <<"userdb-717578">>,
         SecurityProperties = [
-            {<<"admins">>,{[{<<"names">>,[<<"foo">>,<<"bar">>]}]}},
-            {<<"members">>,{[{<<"names">>,[<<"baz">>,<<"pow">>]}]}}
+            {<<"admins">>, {[{<<"names">>, [<<"foo">>, <<"bar">>]}]}},
+            {<<"members">>, {[{<<"names">>, [<<"baz">>, <<"pow">>]}]}}
         ],
         create_db(UserDbName),
         set_security(UserDbName, SecurityProperties),
         create_user(TestAuthDb, User),
         wait_for_security_create(<<"admins">>, User, UserDbName),
-        {AdminProperties} = proplists:get_value(<<"admins">>,
-            get_security(UserDbName)),
+        {AdminProperties} = proplists:get_value(
+            <<"admins">>,
+            get_security(UserDbName)
+        ),
         AdminNames = proplists:get_value(<<"names">>, AdminProperties),
         ?assert(lists:member(<<"foo">>, AdminNames)),
         ?assert(lists:member(<<"bar">>, AdminNames)),
@@ -372,15 +391,17 @@ should_not_remove_existing_db_members(TestAuthDb) ->
         User = "qux",
         UserDbName = <<"userdb-717578">>,
         SecurityProperties = [
-            {<<"admins">>,{[{<<"names">>,[<<"pow">>,<<"wow">>]}]}},
-            {<<"members">>,{[{<<"names">>,[<<"pow">>,<<"wow">>]}]}}
+            {<<"admins">>, {[{<<"names">>, [<<"pow">>, <<"wow">>]}]}},
+            {<<"members">>, {[{<<"names">>, [<<"pow">>, <<"wow">>]}]}}
         ],
         create_db(UserDbName),
         set_security(UserDbName, SecurityProperties),
         create_user(TestAuthDb, User),
         wait_for_security_create(<<"members">>, User, UserDbName),
-        {MemberProperties} = proplists:get_value(<<"members">>,
-            get_security(UserDbName)),
+        {MemberProperties} = proplists:get_value(
+            <<"members">>,
+            get_security(UserDbName)
+        ),
         MemberNames = proplists:get_value(<<"names">>, MemberProperties),
         ?assert(lists:member(<<"pow">>, MemberNames)),
         ?assert(lists:member(<<"wow">>, MemberNames)),
@@ -392,23 +413,27 @@ should_remove_user_from_db_admins(TestAuthDb) ->
         User = "qux",
         UserDbName = <<"userdb-717578">>,
         SecurityProperties = [
-            {<<"admins">>,{[{<<"names">>,[<<"foo">>,<<"bar">>]}]}},
-            {<<"members">>,{[{<<"names">>,[<<"baz">>,<<"pow">>]}]}}
+            {<<"admins">>, {[{<<"names">>, [<<"foo">>, <<"bar">>]}]}},
+            {<<"members">>, {[{<<"names">>, [<<"baz">>, <<"pow">>]}]}}
         ],
         create_db(UserDbName),
         set_security(UserDbName, SecurityProperties),
         create_user(TestAuthDb, User),
         wait_for_security_create(<<"admins">>, User, UserDbName),
-        {AdminProperties} = proplists:get_value(<<"admins">>,
-            get_security(UserDbName)),
+        {AdminProperties} = proplists:get_value(
+            <<"admins">>,
+            get_security(UserDbName)
+        ),
         AdminNames = proplists:get_value(<<"names">>, AdminProperties),
         FooBefore = lists:member(<<"foo">>, AdminNames),
         BarBefore = lists:member(<<"bar">>, AdminNames),
         QuxBefore = lists:member(<<"qux">>, AdminNames),
         delete_user(TestAuthDb, User),
         wait_for_security_delete(<<"admins">>, User, UserDbName),
-        {NewAdminProperties} = proplists:get_value(<<"admins">>,
-            get_security(UserDbName)),
+        {NewAdminProperties} = proplists:get_value(
+            <<"admins">>,
+            get_security(UserDbName)
+        ),
         NewAdminNames = proplists:get_value(<<"names">>, NewAdminProperties),
         FooAfter = lists:member(<<"foo">>, NewAdminNames),
         BarAfter = lists:member(<<"bar">>, NewAdminNames),
@@ -426,23 +451,27 @@ should_remove_user_from_db_members(TestAuthDb) ->
         User = "qux",
         UserDbName = <<"userdb-717578">>,
         SecurityProperties = [
-            {<<"admins">>,{[{<<"names">>,[<<"pow">>,<<"wow">>]}]}},
-            {<<"members">>,{[{<<"names">>,[<<"pow">>,<<"wow">>]}]}}
+            {<<"admins">>, {[{<<"names">>, [<<"pow">>, <<"wow">>]}]}},
+            {<<"members">>, {[{<<"names">>, [<<"pow">>, <<"wow">>]}]}}
         ],
         create_db(UserDbName),
         set_security(UserDbName, SecurityProperties),
         create_user(TestAuthDb, User),
         wait_for_security_create(<<"members">>, User, UserDbName),
-        {MemberProperties} = proplists:get_value(<<"members">>,
-            get_security(UserDbName)),
+        {MemberProperties} = proplists:get_value(
+            <<"members">>,
+            get_security(UserDbName)
+        ),
         MemberNames = proplists:get_value(<<"names">>, MemberProperties),
         PowBefore = lists:member(<<"pow">>, MemberNames),
         WowBefore = lists:member(<<"wow">>, MemberNames),
         QuxBefore = lists:member(<<"qux">>, MemberNames),
         delete_user(TestAuthDb, User),
         wait_for_security_delete(<<"members">>, User, UserDbName),
-        {NewMemberProperties} = proplists:get_value(<<"members">>,
-            get_security(UserDbName)),
+        {NewMemberProperties} = proplists:get_value(
+            <<"members">>,
+            get_security(UserDbName)
+        ),
         NewMemberNames = proplists:get_value(<<"names">>, NewMemberProperties),
         PowAfter = lists:member(<<"pow">>, NewMemberNames),
         WowAfter = lists:member(<<"wow">>, NewMemberNames),
@@ -455,12 +484,11 @@ should_remove_user_from_db_members(TestAuthDb) ->
         ?assertNot(QuxAfter)
     end).
 
-
-
 wait_for_db_create(UserDbName) ->
     test_util:wait(fun() ->
         case all_dbs_with_errors() of
-            {error, _, _ , _} -> wait;
+            {error, _, _, _} ->
+                wait;
             {ok, _, _, AllDbs} ->
                 case lists:member(UserDbName, AllDbs) of
                     true -> true;
@@ -472,7 +500,8 @@ wait_for_db_create(UserDbName) ->
 wait_for_db_delete(UserDbName) ->
     test_util:wait(fun() ->
         case all_dbs_with_errors() of
-            {ok, 500, _ , _} -> wait;
+            {ok, 500, _, _} ->
+                wait;
             {ok, _, _, AllDbs} ->
                 case not lists:member(UserDbName, AllDbs) of
                     true -> true;
@@ -508,10 +537,12 @@ couch_peruser_test_() ->
         "couch_peruser test",
         {
             setup,
-            fun setup_all/0, fun teardown_all/1,
+            fun setup_all/0,
+            fun teardown_all/1,
             {
                 foreach,
-                fun setup/0, fun teardown/1,
+                fun setup/0,
+                fun teardown/1,
                 [
                     fun should_create_anon_user_db_with_default/1,
                     fun should_create_anon_user_db_with_custom_prefix/1,
