@@ -59,11 +59,9 @@
 
 -export([
     init/1,
-    terminate/2,
     handle_call/3,
     handle_cast/2,
     handle_info/2,
-    code_change/3,
     format_status/2
 ]).
 
@@ -131,9 +129,6 @@ cleanup({Pid, _Epoch, Timeout}) ->
 init([#state{} = State]) ->
     {ok, State}.
 
-terminate(_Reason, _State) ->
-    ok.
-
 handle_call({update_headers, Headers, _Epoch}, _From, State) ->
     case maybe_refresh(State) of
         {ok, State1} ->
@@ -159,9 +154,6 @@ handle_info(Msg, State) ->
     couch_log:error("~p : Received un-expected message ~p", [?MODULE, Msg]),
     {noreply, State}.
 
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 format_status(_Opt, [_PDict, State]) ->
     [
         {epoch, State#state.epoch},
@@ -274,20 +266,7 @@ process_auth_failure(Epoch, #state{epoch = Epoch} = State) ->
 
 -spec get_session_url(string()) -> string().
 get_session_url(Url) ->
-    #url{
-        protocol = Proto,
-        host = Host,
-        port = Port
-    } = ibrowse_lib:parse_url(Url),
-    WithPort = lists:concat([Proto, "://", Host, ":", Port]),
-    case lists:prefix(WithPort, Url) of
-        true ->
-            % Explicit port specified in the original url
-            WithPort ++ "/_session";
-        false ->
-            % Implicit proto default port was used
-            lists:concat([Proto, "://", Host, "/_session"])
-    end.
+    uri_string:resolve("/_session", Url).
 
 -spec schedule_refresh(non_neg_integer(), #state{}) -> #state{}.
 schedule_refresh(T, #state{next_refresh = Tc} = State) when T < Tc ->
@@ -307,7 +286,10 @@ maybe_refresh(#state{next_refresh = T} = State) ->
 -spec refresh(#state{}) -> {ok, #state{}} | {error, term()}.
 refresh(#state{session_url = Url, user = User, pass = Pass} = State) ->
     Body = mochiweb_util:urlencode([{name, User}, {password, Pass}]),
-    Headers0 = [{"Content-Type", "application/x-www-form-urlencoded"}],
+    Headers0 = [
+        {"User-Agent", ?COUCH_REPLICATOR_USER_AGENT},
+        {"Content-Type", "application/x-www-form-urlencoded"}
+    ],
     Headers =
         case State#state.require_valid_user of
             true ->
@@ -391,23 +373,50 @@ http_response({error, Error}, #state{session_url = Url, user = User}) ->
     {error, {session_request_failed, Url, User, Error}}.
 
 -spec parse_cookie(list()) -> {ok, age(), string()} | {error, term()}.
-parse_cookie(Headers0) ->
-    Headers = mochiweb_headers:make(Headers0),
-    case mochiweb_headers:get_value("Set-Cookie", Headers) of
-        undefined ->
+parse_cookie(Headers) ->
+    case get_cookies(Headers) of
+        [] ->
             {error, cookie_not_found};
-        CookieHeader ->
-            CookieKVs = mochiweb_cookies:parse_cookie(CookieHeader),
-            CaseInsKVs = mochiweb_headers:make(CookieKVs),
-            case mochiweb_headers:get_value("AuthSession", CaseInsKVs) of
-                undefined ->
-                    {error, cookie_format_invalid};
-                Cookie ->
-                    MaxAge = parse_max_age(CaseInsKVs),
-                    {ok, MaxAge, Cookie}
+        [_ | _] = Cookies ->
+            case get_auth_session_cookies_and_age(Cookies) of
+                [] -> {error, cookie_format_invalid};
+                [{Cookie, MaxAge} | _] -> {ok, MaxAge, Cookie}
             end
     end.
 
+% Return list of cookies from headers, each as a KV list.
+% For example:
+%  [
+%    [{"AuthSession", "foo"}, {"max-age", "1"}],
+%    [{"ApiKey", "Secret"}, {"HttpOnly", []}]
+%  ]
+%
+-spec get_cookies(list()) -> [list()].
+get_cookies(Headers) ->
+    Headers1 = mochiweb_headers:make(Headers),
+    Headers2 = mochiweb_headers:to_list(Headers1),
+    Fun = fun({K, V}) ->
+        case string:equal(K, "Set-Cookie", true) of
+            true -> {true, mochiweb_cookies:parse_cookie(V)};
+            false -> false
+        end
+    end,
+    lists:filtermap(Fun, Headers2).
+
+% From a list of cookies, pick out only AuthSession cookies.
+% Return a list of {Cookie, MaxAge} tuples
+%
+-spec get_auth_session_cookies_and_age([list()]) -> [{string(), age()}].
+get_auth_session_cookies_and_age(Cookies) ->
+    Fun = fun(CookieKVs) ->
+        CaseInsKVs = mochiweb_headers:make(CookieKVs),
+        case mochiweb_headers:get_value("AuthSession", CaseInsKVs) of
+            undefined -> false;
+            Cookie -> {true, {Cookie, parse_max_age(CaseInsKVs)}}
+        end
+    end,
+    lists:filtermap(Fun, Cookies).
+
 -spec parse_max_age(list()) -> age().
 parse_max_age(CaseInsKVs) ->
     case mochiweb_headers:get_value("Max-Age", CaseInsKVs) of
@@ -496,7 +505,13 @@ get_session_url_test_() ->
             {"http://127.0.0.1/db", "http://127.0.0.1/_session"},
             {"http://host/x/y/z", "http://host/_session"},
             {"http://host:5984/db", "http://host:5984/_session"},
-            {"https://host/db?q=1", "https://host/_session"}
+            {"https://host/db?q=1", "https://host/_session"},
+            {"http://[71bf:b7e0:a889:52d5:24a7:fe76:3253:0900]:5984?q=4",
+                "http://[71bf:b7e0:a889:52d5:24a7:fe76:3253:0900]:5984/_session"},
+            {"http://[199f:6f5:f092:ce3e:2b:8062:fa8f:4901]?q=2&n=1",
+                "http://[199f:6f5:f092:ce3e:2b:8062:fa8f:4901]/_session"},
+            {"http://[::1]", "http://[::1]/_session"},
+            {"http://[::1]:1", "http://[::1]:1/_session"}
         ]
     ].
 
@@ -535,7 +550,8 @@ cookie_update_test_() ->
                 t_init_state_401_with_require_valid_user(),
                 t_init_state_404(),
                 t_init_state_no_creds(),
-                t_init_state_http_error()
+                t_init_state_http_error(),
+                t_send_replicator_user_agent()
             ]
         }
     }.
@@ -651,6 +667,18 @@ t_init_state_http_error() ->
         ?assertEqual({session_request_failed, SessionUrl, "u", x}, Error)
     end).
 
+t_send_replicator_user_agent() ->
+    ?_test(begin
+        mock_http_cookie_response("Abc"),
+        {ok, State} = maybe_refresh(#state{next_refresh = 0}),
+        ?assertMatch(#state{epoch = 1, cookie = "Abc"}, State),
+        % Headers is the 3rd argument in send_req_direct/7
+        % See https://hexdocs.pm/meck/meck.html#capture-5
+        Headers = meck:capture(first, ibrowse, send_req_direct, '_', 3),
+        UserAgent = proplists:get_value("User-Agent", Headers),
+        ?assertMatch("CouchDB-Replicator/" ++ _, UserAgent)
+    end).
+
 httpdb(Url) ->
     couch_replicator_utils:normalize_basic_auth(#httpdb{url = Url}).
 
@@ -717,4 +745,59 @@ parse_max_age_test_() ->
         ]
     ].
 
+get_cookies_test() ->
+    ?assertEqual([], get_cookies([])),
+    ?assertEqual([], get_cookies([{"abc", ""}])),
+    ?assertEqual([], get_cookies([{"abc", "def"}])),
+    ?assertEqual([], get_cookies([{"xset-cookie", "c=v"}])),
+    ?assertEqual([], get_cookies([{"set-cookiee", "c=v"}])),
+    ?assertEqual([[]], get_cookies([{"set-cookie", ""}])),
+    ?assertEqual([[{"c", "v"}]], get_cookies([{"Set-cOokie", "c=v"}])),
+    ?assertEqual(
+        [[{"c", "v"}, {"HttpOnly", []}]],
+        get_cookies([
+            {"Set-COOkiE", "c=v;HttpOnly"}
+        ])
+    ),
+    ?assertEqual(
+        [[{"c", "v"}]],
+        get_cookies([
+            {"Foo", "Bar"},
+            {"Set-cOokie", "c=v"}
+        ])
+    ),
+    ?assertEqual(
+        [
+            [{"c1", "v1"}, {"x", "y"}],
+            [{"c2", "v2"}, {"z", ""}]
+        ],
+        get_cookies([
+            {"Set-cOokie", "c1=v1;x=y"},
+            {"Other", "Foo;Bar"},
+            {"sEt-cookie", "c2=v2;z"}
+        ])
+    ).
+
+get_auth_session_cookies_and_age_test() ->
+    ?assertEqual([], get_auth_session_cookies_and_age([])),
+    ?assertEqual([], get_auth_session_cookies_and_age([[{"c", "v"}]])),
+    ?assertEqual(
+        [{"x", undefined}],
+        get_auth_session_cookies_and_age([
+            [{"c", "v"}], [{"AuthSession", "x"}], [{"z", "w"}]
+        ])
+    ),
+    ?assertEqual(
+        [
+            {"x", 10},
+            {"y", 20},
+            {"z", undefined}
+        ],
+        get_auth_session_cookies_and_age([
+            [{"AuthSession", "x"}, {"Max-Age", "10"}, {"HttpOnly", ""}],
+            [{"AuthSession", "y"}, {"Max-Age", "20"}],
+            [{"AuthSession", "z"}, {"Foo", "Bar"}]
+        ])
+    ).
+
 -endif.
