@@ -12,7 +12,6 @@
 
 -module(couch_replicator_httpc_pool).
 -behaviour(gen_server).
--vsn(1).
 
 % public API
 -export([start_link/2, start_link/3, stop/1]).
@@ -20,7 +19,7 @@
 
 % gen_server API
 -export([init/1, handle_call/3, handle_info/2, handle_cast/2]).
--export([code_change/3, terminate/2, format_status/2]).
+-export([format_status/2]).
 
 -include_lib("couch/include/couch_db.hrl").
 
@@ -136,12 +135,6 @@ handle_info({'DOWN', Ref, process, _, _}, #state{callers = Callers} = State) ->
             {noreply, State}
     end.
 
-code_change(_OldVsn, #state{} = State, _Extra) ->
-    {ok, State}.
-
-terminate(_Reason, _State) ->
-    ok.
-
 format_status(_Opt, [_PDict, State]) ->
     #state{
         url = Url,
