@@ -15,7 +15,8 @@
 -behaviour(gen_server).
 
 -export([
-    start_link/1
+    start_link/1,
+    stop/1
 ]).
 
 -export([
@@ -24,7 +25,6 @@
     handle_call/3,
     handle_info/2,
     handle_cast/2,
-    code_change/3,
     format_status/2,
     sum_stats/2,
     report_seq_done/3
@@ -78,7 +78,8 @@
     use_checkpoints = true,
     checkpoint_interval = ?DEFAULT_CHECKPOINT_INTERVAL,
     type = db,
-    view = nil
+    view = nil,
+    certificate_checker
 }).
 
 start_link(#rep{id = Id = {BaseId, Ext}, source = Src, target = Tgt} = Rep) ->
@@ -102,6 +103,23 @@ start_link(#rep{id = Id = {BaseId, Ext}, source = Src, target = Tgt} = Rep) ->
             {error, {already_started, OtherPid}}
     end.
 
+stop(Pid) when is_pid(Pid) ->
+    Ref = erlang:monitor(process, Pid),
+    unlink(Pid),
+    % In the rare case the job is already stopping as we try to stop it, it
+    % won't return ok but exit the calling process, usually the scheduler, so
+    % we guard against that. See:
+    %  www.erlang.org/doc/apps/stdlib/gen_server.html#stop/3
+    catch gen_server:stop(Pid, shutdown, infinity),
+    receive
+        {'DOWN', Ref, _, _, Reason} -> Reason
+    end,
+    receive
+        {'EXIT', Pid, _} -> ok
+    after 0 -> ok
+    end,
+    ok.
+
 init(InitArgs) ->
     {ok, InitArgs, 0}.
 
@@ -175,6 +193,8 @@ do_init(#rep{options = Options, id = {BaseId, Ext}, user_ctx = UserCtx} = Rep) -
     % unfortunately not immune to race conditions.
 
     log_replication_start(State),
+    CertificateCheckerPid = verify_ssl_certificates_log(Rep),
+
     couch_log:debug("Worker pids are: ~p", [Workers]),
 
     doc_update_triggered(Rep),
@@ -183,6 +203,7 @@ do_init(#rep{options = Options, id = {BaseId, Ext}, user_ctx = UserCtx} = Rep) -
         changes_queue = ChangesQueue,
         changes_manager = ChangesManager,
         changes_reader = ChangesReader,
+        certificate_checker = CertificateCheckerPid,
         workers = Workers
     }}.
 
@@ -269,6 +290,8 @@ handle_info({'EXIT', Pid, {shutdown, max_backoff}}, State) ->
     {stop, {shutdown, max_backoff}, State};
 handle_info({'EXIT', Pid, normal}, #rep_state{changes_reader = Pid} = State) ->
     {noreply, State};
+handle_info({'EXIT', Pid, _Reason}, #rep_state{certificate_checker = Pid} = State) ->
+    {noreply, State};
 handle_info({'EXIT', Pid, Reason0}, #rep_state{changes_reader = Pid} = State) ->
     couch_stats:increment_counter([couch_replicator, changes_reader_deaths]),
     Reason =
@@ -452,9 +475,6 @@ terminate_cleanup(#rep_state{rep_details = #rep{id = RepId}} = State) ->
     couch_replicator_api_wrap:db_close(State#rep_state.source),
     couch_replicator_api_wrap:db_close(State#rep_state.target).
 
-code_change(_OldVsn, #rep_state{} = State, _Extra) ->
-    {ok, State}.
-
 format_status(_Opt, [_PDict, State]) ->
     #rep_state{
         source = Source,
@@ -500,7 +520,7 @@ startup_jitter() ->
         "startup_jitter",
         ?STARTUP_JITTER_DEFAULT
     ),
-    couch_rand:uniform(erlang:max(1, Jitter)).
+    rand:uniform(erlang:max(1, Jitter)).
 
 headers_strip_creds([], Acc) ->
     lists:reverse(Acc);
@@ -1148,6 +1168,14 @@ log_replication_start(#rep_state{rep_details = Rep} = RepState) ->
         " worker_batch_size:~p session_id:~s",
     couch_log:notice(Msg, [Id, Source, Target, From, Workers, BatchSize, Sid]).
 
+verify_ssl_certificates_log(#rep{} = Rep) ->
+    case config:get_boolean("replicator", "verify_ssl_certificates_log", false) of
+        true ->
+            spawn_link(couch_replicator_utils, verify_ssl_certificates_log, [Rep]);
+        false ->
+            undefined
+    end.
+
 -ifdef(TEST).
 
 -include_lib("couch/include/couch_eunit.hrl").
