@@ -13,6 +13,7 @@
 -module(couch_replicator_utils).
 
 -export([
+    owner/2,
     replication_id/2,
     sum_stats/2,
     is_deleted/1,
@@ -27,19 +28,33 @@
     get_basic_auth_creds/1,
     remove_basic_auth_creds/1,
     normalize_basic_auth/1,
-    seq_encode/1
+    seq_encode/1,
+    valid_endpoint_protocols_log/1,
+    verify_ssl_certificates_log/1
 ]).
 
 -include_lib("ibrowse/include/ibrowse.hrl").
 -include_lib("couch/include/couch_db.hrl").
+-include_lib("mem3/include/mem3.hrl").
 -include("couch_replicator.hrl").
 -include_lib("couch_replicator/include/couch_replicator_api_wrap.hrl").
+-include_lib("public_key/include/public_key.hrl").
 
 -import(couch_util, [
     get_value/2,
     get_value/3
 ]).
 
+-spec owner(Dbname :: binary(), DocId :: binary()) -> node().
+owner(<<"shards/", _/binary>> = ShardName, DocId) ->
+    DbName = mem3:dbname(ShardName),
+    Live = [node() | nodes()],
+    Shards = mem3:shards(DbName, DocId),
+    Nodes = [N || #shard{node = N} <- Shards, lists:member(N, Live)],
+    mem3:owner(DbName, DocId, Nodes);
+owner(_ShardName, _DocId) ->
+    node().
+
 rep_error_to_binary(Error) ->
     couch_util:to_binary(error_reason(Error)).
 
@@ -140,7 +155,8 @@ decode_basic_creds(Base64) ->
             {undefined, undefined}
     catch
         % Tolerate invalid B64 values here to avoid crashing replicator
-        error:function_clause ->
+        % Changed to `missing_padding` in OTP 26
+        error:Reason when Reason =:= function_clause; Reason =:= missing_padding ->
             {undefined, undefined}
     end.
 
@@ -218,20 +234,20 @@ set_basic_auth_creds(User, Pass, #httpdb{} = HttpDb) when
 
 -spec extract_creds_from_url(string()) ->
     {ok, {string() | undefined, string() | undefined}, string()}
-    | {error, term()}.
+    | {error, term(), term()}.
 extract_creds_from_url(Url) ->
-    case ibrowse_lib:parse_url(Url) of
-        {error, Error} ->
-            {error, Error};
-        #url{username = undefined, password = undefined} ->
-            {ok, {undefined, undefined}, Url};
-        #url{protocol = Proto, username = User, password = Pass} ->
-            % Excise user and pass parts from the url. Try to keep the host,
-            % port and path as they were in the original.
-            Prefix = lists:concat([Proto, "://", User, ":", Pass, "@"]),
-            Suffix = lists:sublist(Url, length(Prefix) + 1, length(Url) + 1),
-            NoCreds = lists:concat([Proto, "://", Suffix]),
-            {ok, {User, Pass}, NoCreds}
+    case uri_string:parse(Url) of
+        {error, Type, Error} ->
+            {error, Type, Error};
+        #{userinfo := UserPass} = UriMap ->
+            UriMap1 = maps:remove(userinfo, UriMap),
+            NoCreds = uri_string:recompose(UriMap1),
+            case string:split(UserPass, ":") of
+                [User, Pass] -> {ok, {User, Pass}, NoCreds};
+                [_] -> {ok, {undefined, undefined}, NoCreds}
+            end;
+        #{} ->
+            {ok, {undefined, undefined}, Url}
     end.
 
 % Normalize basic auth credentials so they are set only in the auth props
@@ -249,7 +265,7 @@ normalize_basic_auth(#httpdb{} = HttpDb) ->
         case extract_creds_from_url(Url) of
             {ok, Creds = {_, _}, UrlNoCreds} ->
                 {Creds, UrlNoCreds};
-            {error, _Error} ->
+            {error, _Tag, _Detail} ->
                 % Don't crash replicator if user provided an invalid
                 % userinfo part
                 {undefined, undefined}
@@ -276,6 +292,116 @@ seq_encode(Seq) ->
     % object. We are being maximally compatible here.
     ?JSON_ENCODE(Seq).
 
+%% Log uses of http protocol
+valid_endpoint_protocols_log(#rep{source = undefined, target = undefined}) ->
+    % When we cancel continuous transient replications (with a POST to _replicate)
+    % source and target will be undefined
+    ok;
+valid_endpoint_protocols_log(#rep{} = Rep) ->
+    VerifyEnabled = config:get_boolean("replicator", "valid_endpoint_protocols_log", false),
+    case VerifyEnabled of
+        true ->
+            ok = check_endpoint_protocols(Rep, source),
+            ok = check_endpoint_protocols(Rep, target);
+        false ->
+            ok
+    end.
+
+check_endpoint_protocols(#rep{} = Rep, Type) ->
+    Url = url_from_type(Rep, Type),
+    #url{protocol = Protocol} = ibrowse_lib:parse_url(Url),
+    case Protocol of
+        http ->
+            couch_log:warning("**security warning** replication ~s has insecure ~s at ~s", [
+                rep_principal(Rep), Type, Url
+            ]),
+            ok;
+        _Else ->
+            ok
+    end.
+
+url_from_type(#rep{} = Rep, source) ->
+    Rep#rep.source#httpdb.url;
+url_from_type(#rep{} = Rep, target) ->
+    Rep#rep.target#httpdb.url.
+
+%% log uses of https protocol where verify_peer would fail.
+verify_ssl_certificates_log(#rep{} = Rep) ->
+    ok = check_ssl_certificates(Rep, source),
+    ok = check_ssl_certificates(Rep, target).
+
+check_ssl_certificates(#rep{} = Rep, Type) ->
+    VerifyEnabled = config:get_boolean("replicator", "verify_ssl_certificates", false),
+    CACertFile = config:get("replicator", "ssl_trusted_certificates_file"),
+    if
+        VerifyEnabled ->
+            % no need for an extra check if we're doing them anyway.
+            ok;
+        CACertFile == undefined ->
+            couch_log:warning(
+                "security warnings enabled but no ssl_trusted_certificates_file configured",
+                []
+            ),
+            ok;
+        true ->
+            Url = url_from_type(Rep, Type),
+            try
+                ibrowse:send_req(Url, [], head, [], [
+                    {is_ssl, true},
+                    {ssl_options, [
+                        {cacertfile, CACertFile},
+                        {verify, verify_peer},
+                        {customize_hostname_check, [
+                            {match_fun, public_key:pkix_verify_hostname_match_fun(https)}
+                        ]},
+                        {verify_fun, check_certificate_fun(Rep, Url, Type)}
+                    ]}
+                ])
+            catch
+                Class:Reason ->
+                    couch_log:warning("failed to check certificate of ~s (~p:~p)", [
+                        Url, Class, Reason
+                    ])
+            end,
+            ok
+    end.
+
+check_certificate_fun(#rep{} = Rep, Url, Type) ->
+    Fun = fun
+        (_, {bad_cert, Reason}, UserState) ->
+            couch_log:warning(
+                "**security warning** replication ~s has bad cert in ~s for reason ~p at ~s", [
+                    rep_principal(Rep), Type, Reason, Url
+                ]
+            ),
+            {valid, UserState};
+        (_, {extension, #'Extension'{critical = true} = Ext}, UserState) ->
+            couch_log:warning(
+                "**security warning** replication ~s has unsupported critical extension in ~s of id ~p at ~s",
+                [
+                    rep_principal(Rep), Ext#'Extension'.extnID, Url
+                ]
+            ),
+            {valid, UserState};
+        (_, {extension, _}, UserState) ->
+            {unknown, UserState};
+        (_, valid, UserState) ->
+            {valid, UserState};
+        (_, valid_peer, UserState) ->
+            {valid, UserState}
+    end,
+    InitialState = [],
+    {Fun, InitialState}.
+
+rep_principal(#rep{db_name = DbName} = Rep) when is_binary(DbName) ->
+    io_lib:format("in database ~s, docid ~s", [
+        mem3:dbname(DbName), Rep#rep.doc_id
+    ]);
+rep_principal(#rep{user_ctx = #user_ctx{name = Name}}) when is_binary(Name) ->
+    io_lib:format("by user ~s", [Name]);
+rep_principal(#rep{}) ->
+    "by unknown principal".
+
 -ifdef(TEST).
 
 -include_lib("couch/include/couch_eunit.hrl").
@@ -477,6 +603,24 @@ normalize_basic_creds_test_() ->
                     auth_props = auth_props("u", "p")
                 }
             },
+            {
+                #httpdb{url = "http://u:p@[::1]:42/db?q=2"},
+                #httpdb{
+                    url = "http://[::1]:42/db?q=2",
+                    auth_props = auth_props("u", "p")
+                }
+            },
+            {
+                #httpdb{url = "http://secretjunk@[::1]:42/db?q=2"},
+                #httpdb{url = "http://[::1]:42/db?q=2"}
+            },
+            {
+                #httpdb{url = "http://u:p:p@[::1]:42/db?q=2"},
+                #httpdb{
+                    url = "http://[::1]:42/db?q=2",
+                    auth_props = auth_props("u", "p:p")
+                }
+            },
             {
                 #httpdb{
                     url = "http://h/db",
@@ -575,4 +719,63 @@ auth_props(User, Pass) when is_list(User), is_list(Pass) ->
             ]}}
     ].
 
+http_log_setup() ->
+    Ctx = test_util:start_couch(),
+    config:set("replicator", "valid_endpoint_protocols_log", "true", false),
+    meck:new(couch_log, [passthrough]),
+    Ctx.
+
+http_log_teardown(Ctx) ->
+    meck:unload(),
+    config:delete("replicator", "valid_endpoint_protocols_log", false),
+    test_util:stop_couch(Ctx).
+
+valid_protocol_log_test_() ->
+    {
+        foreach,
+        fun http_log_setup/0,
+        fun http_log_teardown/1,
+        [
+            ?TDEF_FE(t_warn_on_http_urls),
+            ?TDEF_FE(t_dont_warn_on_https_urls),
+            ?TDEF_FE(t_dont_warn_if_disabled),
+            ?TDEF_FE(t_allow_canceling_transient_jobs)
+        ]
+    }.
+
+t_warn_on_http_urls(_) ->
+    Rep = #rep{
+        source = #httpdb{url = "http://foo.local"},
+        target = #httpdb{url = "http://127.0.0.2"}
+    },
+    meck:reset(couch_log),
+    ?assertEqual(ok, valid_endpoint_protocols_log(Rep)),
+    ?assertEqual(2, meck:num_calls(couch_log, warning, 2)).
+
+t_dont_warn_on_https_urls(_) ->
+    Rep = #rep{
+        source = #httpdb{url = "https://foo.local"},
+        target = #httpdb{url = "https://127.0.0.2"}
+    },
+    meck:reset(couch_log),
+    ?assertEqual(ok, valid_endpoint_protocols_log(Rep)),
+    ?assertEqual(0, meck:num_calls(couch_log, warning, 2)).
+
+t_dont_warn_if_disabled(_) ->
+    config:set("replicator", "valid_endpoint_protocols_log", "false", false),
+    Rep = #rep{
+        source = #httpdb{url = "http://foo.local"},
+        target = #httpdb{url = "http://127.0.0.2"}
+    },
+    meck:reset(couch_log),
+    ?assertEqual(ok, valid_endpoint_protocols_log(Rep)),
+    ?assertEqual(0, meck:num_calls(couch_log, warning, 2)).
+
+t_allow_canceling_transient_jobs(_) ->
+    meck:reset(couch_log),
+    % Transient job rep cancel records don't have any source or
+    % target endpoints defined. They are left undefined.
+    ?assertEqual(ok, valid_endpoint_protocols_log(#rep{})),
+    ?assertEqual(0, meck:num_calls(couch_log, warning, 2)).
+
 -endif.
