@@ -174,6 +174,8 @@ replicate(Source, Target) ->
         ]}
     ).
 
+replicate(#{} = RepObject) ->
+    replicate(jiffy:decode(jiffy:encode(RepObject)));
 replicate({[_ | _]} = RepObject) ->
     {ok, Rep} = couch_replicator_parse:parse_rep_doc(RepObject, ?ADMIN_USER),
     ok = couch_replicator_scheduler:add_job(Rep),
@@ -204,7 +206,6 @@ test_setup() ->
     Hashed = couch_passwords:hash_admin_password(?PASSWORD),
     Persist = false,
     ok = config:set("admins", ?USERNAME, ?b2l(Hashed), Persist),
-    ok = config:set("replicator", "cluster_start_period", "0", Persist),
     Source = setup_db(),
     Target = setup_db(),
     {Ctx, {Source, Target}}.
@@ -215,5 +216,4 @@ test_teardown({Ctx, {Source, Target}}) ->
     teardown_db(Target),
     Persist = false,
     config:delete("admins", ?USERNAME, Persist),
-    config:delete("replicator", "cluster_start_period", Persist),
     ok = test_util:stop_couch(Ctx).
