@@ -23,9 +23,7 @@
     init/1,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3,
-    terminate/2
+    handle_info/2
 ]).
 
 -record(st, {}).
@@ -72,9 +70,3 @@ handle_info({'DOWN', Ref, _, _, _} = Msg, State) ->
 handle_info(Msg, State) ->
     error_logger:error_msg("~p received unknown message ~p", [?MODULE, Msg]),
     {noreply, State}.
-
-terminate(_Reason, _State) ->
-    ok.
-
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
