@@ -12,12 +12,9 @@
 
 -module(ddoc_cache_open_error_test).
 
-
--include_lib("couch/include/couch_db.hrl").
--include_lib("eunit/include/eunit.hrl").
+-include_lib("couch/include/couch_eunit.hrl").
 -include("ddoc_cache_test.hrl").
 
-
 start_couch() ->
     Ctx = ddoc_cache_tutil:start_couch(),
     meck:expect(fabric, open_doc, fun(_, ?FOOBAR, _) ->
@@ -25,22 +22,19 @@ start_couch() ->
     end),
     Ctx.
 
-
 stop_couch(Ctx) ->
     meck:unload(),
     ddoc_cache_tutil:stop_couch(Ctx).
 
-
 check_open_error_test_() ->
     {
         setup,
         fun start_couch/0,
         fun stop_couch/1,
-        ddoc_cache_tutil:with([
-            {"handle_open_error", fun handle_open_error/1}
+        with([
+            ?TDEF(handle_open_error)
         ])
     }.
 
-
 handle_open_error({DbName, _}) ->
     ?assertError(test_kaboom, ddoc_cache:open_doc(DbName, ?FOOBAR)).
