@@ -16,7 +16,6 @@
 
 -module(dreyfus_index).
 -behaviour(gen_server).
--vsn(1).
 -include_lib("couch/include/couch_db.hrl").
 -include("dreyfus.hrl").
 
@@ -37,9 +36,7 @@
     init/1,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    terminate/2,
-    code_change/3
+    handle_info/2
 ]).
 
 % private definitions.
@@ -288,12 +285,6 @@ handle_info(
     [gen_server:reply(P, {error, Reason}) || {P, _} <- WaitList],
     {stop, normal, State}.
 
-terminate(_Reason, _State) ->
-    ok.
-
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 % private functions.
 
 open_index(DbName, #index{analyzer = Analyzer, sig = Sig}) ->
@@ -327,7 +318,7 @@ design_doc_to_index(#doc{id = Id, body = {Fields}}, IndexName) ->
                     Sig = ?l2b(
                         couch_util:to_hex(
                             couch_hash:md5_hash(
-                                term_to_binary({Analyzer, Def})
+                                ?term_to_bin({Analyzer, Def})
                             )
                         )
                     ),
@@ -362,7 +353,7 @@ index_name(#index{dbname = DbName, ddoc_id = DDocId, name = IndexName}) ->
 
 args_to_proplist(#index_query_args{} = Args) ->
     [
-        {'query', Args#index_query_args.q},
+        {query, Args#index_query_args.q},
         {partition, Args#index_query_args.partition},
         {limit, Args#index_query_args.limit},
         {refresh, Args#index_query_args.stale =:= false},
@@ -381,7 +372,7 @@ args_to_proplist(#index_query_args{} = Args) ->
 
 args_to_proplist2(#index_query_args{} = Args) ->
     [
-        {'query', Args#index_query_args.q},
+        {query, Args#index_query_args.q},
         {field, Args#index_query_args.grouping#grouping.by},
         {refresh, Args#index_query_args.stale =:= false},
         {groups, Args#index_query_args.grouping#grouping.groups},
