@@ -12,8 +12,12 @@
 
 -module(fabric_db_meta).
 
--export([set_revs_limit/3, set_security/3, get_all_security/2,
-    set_purge_infos_limit/3]).
+-export([
+    set_revs_limit/3,
+    set_security/3,
+    get_all_security/2,
+    set_purge_infos_limit/3
+]).
 
 -include_lib("fabric/include/fabric.hrl").
 -include_lib("mem3/include/mem3.hrl").
@@ -25,20 +29,19 @@
     num_workers
 }).
 
-
 set_revs_limit(DbName, Limit, Options) ->
     Shards = mem3:shards(DbName),
     Workers = fabric_util:submit_jobs(Shards, set_revs_limit, [Limit, Options]),
     Handler = fun handle_revs_message/3,
     Acc0 = {Workers, length(Workers) - 1},
     case fabric_util:recv(Workers, #shard.ref, Handler, Acc0) of
-    {ok, ok} ->
-        ok;
-    {timeout, {DefunctWorkers, _}} ->
-        fabric_util:log_timeout(DefunctWorkers, "set_revs_limit"),
-        {error, timeout};
-    Error ->
-        Error
+        {ok, ok} ->
+            ok;
+        {timeout, {DefunctWorkers, _}} ->
+            fabric_util:log_timeout(DefunctWorkers, "set_revs_limit"),
+            {error, timeout};
+        Error ->
+            Error
     end.
 
 handle_revs_message(ok, _, {_Workers, 0}) ->
@@ -48,7 +51,6 @@ handle_revs_message(ok, Worker, {Workers, Waiting}) ->
 handle_revs_message(Error, _, _Acc) ->
     {error, Error}.
 
-
 set_purge_infos_limit(DbName, Limit, Options) ->
     Shards = mem3:shards(DbName),
     Workers = fabric_util:submit_jobs(Shards, set_purge_infos_limit, [Limit, Options]),
@@ -71,35 +73,34 @@ handle_purge_message(ok, Worker, {Workers, Waiting}) ->
 handle_purge_message(Error, _, _Acc) ->
     {error, Error}.
 
-
 set_security(DbName, SecObj, Options) ->
     Shards = mem3:shards(DbName),
     RexiMon = fabric_util:create_monitors(Shards),
     Workers = fabric_util:submit_jobs(Shards, set_security, [SecObj, Options]),
     Handler = fun handle_set_message/3,
     Acc = #acc{
-        workers=Workers,
-        finished=[],
-        num_workers=length(Workers)
+        workers = Workers,
+        finished = [],
+        num_workers = length(Workers)
     },
     try fabric_util:recv(Workers, #shard.ref, Handler, Acc) of
-    {ok, #acc{finished=Finished}} ->
-        case check_sec_set(length(Workers), Finished) of
-            ok -> ok;
-            Error -> Error
-        end;
-    {timeout, #acc{workers=DefunctWorkers}} ->
-        fabric_util:log_timeout(DefunctWorkers, "set_security"),
-        {error, timeout};
-    Error ->
-        Error
+        {ok, #acc{finished = Finished}} ->
+            case check_sec_set(length(Workers), Finished) of
+                ok -> ok;
+                Error -> Error
+            end;
+        {timeout, #acc{workers = DefunctWorkers}} ->
+            fabric_util:log_timeout(DefunctWorkers, "set_security"),
+            {error, timeout};
+        Error ->
+            Error
     after
         rexi_monitor:stop(RexiMon)
     end.
 
-handle_set_message({rexi_DOWN, _, {_, Node}, _}, _, #acc{workers=Wrkrs}=Acc) ->
+handle_set_message({rexi_DOWN, _, {_, Node}, _}, _, #acc{workers = Wrkrs} = Acc) ->
     RemWorkers = lists:filter(fun(S) -> S#shard.node =/= Node end, Wrkrs),
-    maybe_finish_set(Acc#acc{workers=RemWorkers});
+    maybe_finish_set(Acc#acc{workers = RemWorkers});
 handle_set_message(ok, W, Acc) ->
     NewAcc = Acc#acc{
         workers = (Acc#acc.workers -- [W]),
@@ -115,9 +116,9 @@ handle_set_message(Error, W, Acc) ->
     NewAcc = Acc#acc{workers = (Acc#acc.workers -- [W])},
     maybe_finish_set(NewAcc).
 
-maybe_finish_set(#acc{workers=[]}=Acc) ->
+maybe_finish_set(#acc{workers = []} = Acc) ->
     {stop, Acc};
-maybe_finish_set(#acc{finished=Finished, num_workers=NumWorkers}=Acc) ->
+maybe_finish_set(#acc{finished = Finished, num_workers = NumWorkers} = Acc) ->
     case check_sec_set(NumWorkers, Finished) of
         ok -> {stop, Acc};
         _ -> {ok, Acc}
@@ -126,8 +127,9 @@ maybe_finish_set(#acc{finished=Finished, num_workers=NumWorkers}=Acc) ->
 check_sec_set(NumWorkers, SetWorkers) ->
     try
         check_sec_set_int(NumWorkers, SetWorkers)
-    catch throw:Reason ->
-        {error, Reason}
+    catch
+        throw:Reason ->
+            {error, Reason}
     end.
 
 check_sec_set_int(NumWorkers, SetWorkers) ->
@@ -143,41 +145,41 @@ check_sec_set_int(NumWorkers, SetWorkers) ->
     end,
     ok.
 
-
 get_all_security(DbName, Options) ->
-    Shards = case proplists:get_value(shards, Options) of
-        Shards0 when is_list(Shards0) -> Shards0;
-        _ -> mem3:shards(DbName)
-    end,
+    Shards =
+        case proplists:get_value(shards, Options) of
+            Shards0 when is_list(Shards0) -> Shards0;
+            _ -> mem3:shards(DbName)
+        end,
     RexiMon = fabric_util:create_monitors(Shards),
     Workers = fabric_util:submit_jobs(Shards, get_all_security, [[?ADMIN_CTX]]),
     Handler = fun handle_get_message/3,
     Acc = #acc{
-        workers=Workers,
-        finished=[],
-        num_workers=length(Workers)
+        workers = Workers,
+        finished = [],
+        num_workers = length(Workers)
     },
     try fabric_util:recv(Workers, #shard.ref, Handler, Acc) of
-    {ok, #acc{finished=SecObjs}} when length(SecObjs) > length(Workers) / 2 ->
-        {ok, SecObjs};
-    {ok, _} ->
-        {error, no_majority};
-    {timeout, #acc{workers=DefunctWorkers}} ->
-        fabric_util:log_timeout(
-            DefunctWorkers,
-            "get_all_security"
-        ),
-        {error, timeout};
-    Error ->
-        Error
+        {ok, #acc{finished = SecObjs}} when length(SecObjs) > length(Workers) / 2 ->
+            {ok, SecObjs};
+        {ok, _} ->
+            {error, no_majority};
+        {timeout, #acc{workers = DefunctWorkers}} ->
+            fabric_util:log_timeout(
+                DefunctWorkers,
+                "get_all_security"
+            ),
+            {error, timeout};
+        Error ->
+            Error
     after
         rexi_monitor:stop(RexiMon)
     end.
 
-handle_get_message({rexi_DOWN, _, {_, Node}, _}, _, #acc{workers=Wrkrs}=Acc) ->
+handle_get_message({rexi_DOWN, _, {_, Node}, _}, _, #acc{workers = Wrkrs} = Acc) ->
     RemWorkers = lists:filter(fun(S) -> S#shard.node =/= Node end, Wrkrs),
-    maybe_finish_get(Acc#acc{workers=RemWorkers});
-handle_get_message({Props}=SecObj, W, Acc) when is_list(Props) ->
+    maybe_finish_get(Acc#acc{workers = RemWorkers});
+handle_get_message({Props} = SecObj, W, Acc) when is_list(Props) ->
     NewAcc = Acc#acc{
         workers = (Acc#acc.workers -- [W]),
         finished = [{W, SecObj} | Acc#acc.finished]
@@ -192,7 +194,7 @@ handle_get_message(Error, W, Acc) ->
     NewAcc = Acc#acc{workers = (Acc#acc.workers -- [W])},
     maybe_finish_get(NewAcc).
 
-maybe_finish_get(#acc{workers=[]}=Acc) ->
+maybe_finish_get(#acc{workers = []} = Acc) ->
     {stop, Acc};
 maybe_finish_get(Acc) ->
     {ok, Acc}.
