@@ -199,7 +199,7 @@ spawn_worker_cleaner(Coordinator, Workers, ClientReq) when
         undefined ->
             Pid = spawn(fun() ->
                 erlang:monitor(process, Coordinator),
-                NodeRefSet = set_from_list(shards_to_node_refs(Workers)),
+                NodeRefSet = couch_util:set_from_list(shards_to_node_refs(Workers)),
                 cleaner_loop(Coordinator, NodeRefSet, ClientReq)
             end),
             put(?WORKER_CLEANER, Pid),
@@ -228,9 +228,6 @@ add_worker_to_cleaner(CoordinatorPid, #shard{node = Node, ref = Ref}) ->
             ok
     end.
 
-set_from_list(List) when is_list(List) ->
-    sets:from_list(List, [{version, 2}]).
-
 shards_to_node_refs(Workers) when is_list(Workers) ->
     Fun = fun(#shard{node = Node, ref = Ref}) -> {Node, Ref} end,
     lists:map(Fun, Workers).
@@ -489,13 +486,13 @@ cleanup_called_on_error(_) ->
     ?assert(meck:called(fabric_util, cleanup, 1)).
 
 setup() ->
-    ok = meck:new(rexi_utils, [passthrough]),
-    ok = meck:new(config, [passthrough]),
-    ok = meck:new(fabric_util, [passthrough]),
+    meck:new(rexi_utils, [passthrough]),
+    meck:new(config, [passthrough]),
+    meck:new(fabric_util, [passthrough]),
     meck:expect(config, get, fun(_, _, Default) -> Default end),
-    ok = meck:expect(rexi, kill_all, fun(_) -> ok end),
+    meck:expect(rexi, kill_all, fun(_) -> ok end),
     % Speed up disconnect socket timeout for the test to 200 msec
-    ok = meck:expect(chttpd_util, mochiweb_client_req_check_msec, 0, 200).
+    meck:expect(chttpd_util, mochiweb_client_req_check_msec, 0, 200).
 
 teardown(_) ->
     meck:unload().
