@@ -12,6 +12,7 @@
 import React from 'react';
 import ActiveTasksTableBody from './tablebody';
 import ActiveTasksTableHeader from './tableheader';
+import { Table } from 'react-bootstrap';
 
 export default class ActiveTaskTable extends React.Component {
   render() {
@@ -22,22 +23,25 @@ export default class ActiveTaskTable extends React.Component {
       sortByHeader,
       onTableHeaderClick,
       headerIsAscending,
-      isLoading
+      isLoading,
+      hiddenColumns,
     } = this.props;
 
     return (
       <div id="dashboard-lower-content">
-        <table id="active-tasks-table" className="table table-bordered table-striped active-tasks">
+        <Table striped className="table-active-tasks">
           <ActiveTasksTableHeader
             onTableHeaderClick={onTableHeaderClick}
             sortByHeader={sortByHeader}
-            headerIsAscending={headerIsAscending}/>
+            headerIsAscending={headerIsAscending}
+            hiddenColumns={hiddenColumns}/>
           <ActiveTasksTableBody
             tasks={tasks}
             selectedRadio={selectedRadio}
             isLoading={isLoading}
-            searchTerm={searchTerm}/>
-        </table>
+            searchTerm={searchTerm}
+            hiddenColumns={hiddenColumns}/>
+        </Table>
       </div>
     );
   }
