@@ -18,4 +18,9 @@ export default {
   MANGO_SAVE_INDEX_REQUEST: 'MANGO_SAVE_INDEX_REQUEST',
   MANGO_SHOW_EXPLAIN_RESULTS: 'MANGO_SHOW_EXPLAIN_RESULTS',
   MANGO_HIDE_EXPLAIN_RESULTS: 'MANGO_HIDE_EXPLAIN_RESULTS',
+  MANGO_SET_EXECUTION_STATS_SUPPORTED: 'MANGO_SET_EXECUTION_STATS_SUPPORTED',
+  SET_EXPLAIN_VIEW_FORMAT: 'SET_EXPLAIN_VIEW_FORMAT',
+  EXPLAIN_RESULTS_REDUX_RESET_STATE: 'EXPLAIN_RESULTS_REDUX_RESET_STATE',
+  HIDE_EXPLAIN_REASONS_MODAL: 'HIDE_EXPLAIN_REASONS_MODAL',
+  SHOW_EXPLAIN_REASONS_MODAL: 'SHOW_EXPLAIN_REASONS_MODAL'
 };
