@@ -39,18 +39,11 @@ const getIndexName = ({def, type}) => {
 };
 
 const formatCode = (code) => {
-  return JSON.stringify(code, null, 3);
+  return JSON.stringify(code, null, 2);
 };
 
 const getIndexContent = (doc) => {
-  const content = {
-    ...doc
-  };
-
-  delete content.ddoc;
-  delete content.name;
-
-  return JSON.stringify(content, null, ' ');
+  return JSON.stringify(doc, null, ' ');
 };
 
 export default {
