@@ -16,7 +16,7 @@ module.exports = {
   'Shows the editor for conflicting docs': function (client) {
 
     const waitTime = client.globals.maxWaitTime;
-    const baseUrl = client.globals.test_settings.launch_url;
+    const baseUrl = client.options.launch_url;
 
     client
       .createAnimalDb()
