@@ -24,9 +24,9 @@ module.exports = {
       .loginToGUI()
       .url(baseUrl + '/#/database/' + newDatabaseName + '/_design/keyview/_view/keyview')
       .clickWhenVisible('.control-toggle-queryoptions')
-      .clickWhenVisible('#byKeys', waitTime, false)
-      .setValue('#keys-input', '["document_1"]')
-      .clickWhenVisible('.query-options .btn-secondary')
+      .clickWhenVisible('label[for="byKeys"]', waitTime, false)
+      .setValue('textarea#keys-input', '["document_1"]')
+      .clickWhenVisible('#query-options-tray #button-options .btn-cf-primary')
       .clickWhenVisible('.fonticon-json')
       .waitForElementNotPresent('#doc-list [data-id="document_2"]', waitTime, false)
       .assert.not.elementPresent('#doc-list [data-id="document_2"]')
@@ -46,9 +46,9 @@ module.exports = {
       .loginToGUI()
       .url(baseUrl + '/#/database/' + newDatabaseName + '/_design/keyview/_view/keyview')
       .clickWhenVisible('.control-toggle-queryoptions', waitTime, false)
-      .clickWhenVisible('#byKeys', waitTime, false)
-      .setValue('#keys-input', '["document_1",\n"document_2"]')
-      .clickWhenVisible('.query-options .btn-secondary')
+      .clickWhenVisible('label[for="byKeys"]', waitTime, false)
+      .setValue('textarea#keys-input', '["document_1",\n"document_2"]')
+      .clickWhenVisible('#query-options-tray #button-options .btn-cf-primary')
       .clickWhenVisible('.fonticon-json')
       .waitForElementNotPresent('#doc-list [data-id="document_0"]', waitTime, false)
       .assert.not.elementPresent('#doc-list [data-id="document_0"]')
