@@ -17,24 +17,26 @@ import Components from '../../components/react-components';
 const {ConfirmButton} = Components;
 
 export const ReplicationSubmit = ({onClear, disabled, onClick}) =>
-  <div className="replication__button-row">
-    <ConfirmButton
-      customIcon="fonticon-replicate"
-      id="replicate"
-      text="Start Replication"
-      onClick={onClick}
-      disabled={disabled}
-    />
-    <a
-      className="replication__clear-link"
-      href="#"
-      data-bypass="true"
-      onClick={(e) => {
-        e.preventDefault();
-        onClear();
-      }}>
-    Clear
-    </a>
+  <div className="row mt-3">
+    <div className="col-12 text-end">
+      <a
+        className="replication__clear-link"
+        href="#"
+        data-bypass="true"
+        onClick={(e) => {
+          e.preventDefault();
+          onClear();
+        }}>
+      Clear
+      </a>
+      <ConfirmButton
+        customIcon="fonticon-replicate"
+        id="replicate"
+        text="Start Replication"
+        onClick={onClick}
+        disabled={disabled}
+      />
+    </div>
   </div>;
 
 
