@@ -89,7 +89,8 @@ const initialState = {
   replicateInfo: [],
 
   checkingAPI: true,
-  activitySort: loadActivitySort()
+  activitySort: loadActivitySort(),
+  pageLimit: 100,
 };
 
 const clearForm = (state) => {
@@ -141,6 +142,20 @@ const updateFormField = (state, fieldName, value) => {
     }
   }
 
+  // Set default local source/target database to the first in the list (to match the default dropdown display)
+  if (fieldName === validFieldMap.replicationSource) {
+    const isLocalDB = updateState[validFieldMap.replicationSource] === Constants.REPLICATION_SOURCE.LOCAL;
+    if (isLocalDB && updateState.databases.length > 0) {
+      updateState[validFieldMap.localSource] = updateState.databases[0];
+    }
+  }
+  if (fieldName === validFieldMap.replicationTarget) {
+    const isLocalDB = updateState[validFieldMap.replicationTarget] === Constants.REPLICATION_TARGET.EXISTING_LOCAL_DATABASE;
+    if (isLocalDB && updateState.databases.length > 0) {
+      updateState[validFieldMap.localTarget] = updateState.databases[0];
+    }
+  }
+
   return updateState;
 };
 
@@ -348,6 +363,12 @@ const replication = (state = initialState, {type, options}) => {
         allReplicateSelected: false
       };
 
+    case ActionTypes.REPLICATION_SET_PAGE_LIMIT:
+      return {
+        ...state,
+        pageLimit: options
+      };
+
     default:
       return state;
   }
@@ -406,4 +427,6 @@ export const getReplicateInfo = (state) => {
   });
 };
 
+export const getPageLimit = (state) => state.pageLimit;
+
 export default replication;
