@@ -17,10 +17,8 @@
     extract/2
 ]).
 
-
 -include("mango.hrl").
 
-
 new([]) ->
     {ok, all_fields};
 new(Fields) when is_list(Fields) ->
@@ -28,24 +26,26 @@ new(Fields) when is_list(Fields) ->
 new(Else) ->
     ?MANGO_ERROR({invalid_fields_json, Else}).
 
-
 extract(Doc, undefined) ->
     Doc;
 extract(Doc, all_fields) ->
     Doc;
 extract(Doc, Fields) ->
-    lists:foldl(fun(F, NewDoc) ->
-        {ok, Path} = mango_util:parse_field(F),
-        case mango_doc:get_field(Doc, Path) of
-            not_found ->
-                NewDoc;
-            bad_path ->
-                NewDoc;
-            Value ->
-                mango_doc:set_field(NewDoc, Path, Value)
-        end
-    end, {[]}, Fields).
-
+    lists:foldl(
+        fun(F, NewDoc) ->
+            {ok, Path} = mango_util:parse_field(F),
+            case mango_doc:get_field(Doc, Path) of
+                not_found ->
+                    NewDoc;
+                bad_path ->
+                    NewDoc;
+                Value ->
+                    mango_doc:set_field(NewDoc, Path, Value)
+            end
+        end,
+        {[]},
+        Fields
+    ).
 
 field(Val) when is_binary(Val) ->
     Val;
