@@ -15,7 +15,7 @@ import mango
 import unittest
 import user_docs
 import math
-from hypothesis import given, assume, example
+from hypothesis import given, assume, example, settings
 import hypothesis.strategies as st
 
 
@@ -573,14 +573,14 @@ class NumStringTests(mango.DbPerClass):
     def setUpClass(klass):
         super(NumStringTests, klass).setUpClass()
         klass.db.recreate()
-        if mango.has_text_service():
-            klass.db.create_text_index()
+        klass.db.create_text_index()
 
     # not available for python 2.7.x
     def isFinite(num):
         not (math.isinf(num) or math.isnan(num))
 
     @given(f=st.floats().filter(isFinite).map(str) | st.floats().map(lambda f: f.hex()))
+    @settings(deadline=1000)
     @example("NaN")
     @example("Infinity")
     def test_floating_point_val(self, f):
