@@ -12,14 +12,11 @@
 
 -module(mem3_nodes).
 -behaviour(gen_server).
--vsn(1).
 -export([
     init/1,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    terminate/2,
-    code_change/3
+    handle_info/2
 ]).
 
 -export([start_link/0, get_nodelist/0, get_node_info/2]).
@@ -97,19 +94,13 @@ handle_info(start_listener, #state{update_seq = Seq} = State) ->
 handle_info(_Info, State) ->
     {noreply, State}.
 
-terminate(_Reason, _State) ->
-    ok.
-
-code_change(_OldVsn, #state{} = State, _Extra) ->
-    {ok, State}.
-
 %% internal functions
 
 initialize_nodelist() ->
     DbName = mem3_sync:nodes_db(),
     {ok, Db} = mem3_util:ensure_exists(DbName),
     {ok, _} = couch_db:fold_docs(Db, fun first_fold/2, Db, []),
-    insert_if_missing(Db, [node() | mem3_seeds:get_seeds()]),
+    insert_if_missing(Db, [config:node_name() | mem3_seeds:get_seeds()]),
     Seq = couch_db:get_update_seq(Db),
     couch_db:close(Db),
     Seq.
