@@ -18,6 +18,7 @@
     find_common_seq/4,
     get_missing_revs/4,
     update_docs/4,
+    update_docs/5,
     pull_replication/1,
     load_checkpoint/4,
     load_checkpoint/5,
@@ -61,6 +62,8 @@ get_missing_revs(Node, DbName, IdsRevs, Options) ->
 
 update_docs(Node, DbName, Docs, Options) ->
     rexi_call(Node, {fabric_rpc, update_docs, [DbName, Docs, Options]}).
+update_docs(Node, DbName, Docs, Options, Timeout) ->
+    rexi_call(Node, {fabric_rpc, update_docs, [DbName, Docs, Options]}, Timeout).
 
 load_checkpoint(Node, DbName, SourceNode, SourceUUID, <<>>) ->
     % Upgrade clause for a mixed cluster for old nodes that don't have
@@ -113,7 +116,7 @@ load_checkpoint_rpc(DbName, SourceNode, SourceUUID, FilterHash) ->
                 {ok, Doc} ->
                     rexi:reply({ok, {NewId, Doc}});
                 {not_found, _} ->
-                    OldId = mem3_rep:make_local_id(SourceNode, node()),
+                    OldId = mem3_rep:make_local_id(SourceNode, config:node_name()),
                     case couch_db:open_doc(Db, OldId, []) of
                         {ok, Doc} ->
                             rexi:reply({ok, {NewId, Doc}});
@@ -131,7 +134,7 @@ save_checkpoint_rpc(DbName, Id, SourceSeq, NewEntry0, History0) ->
         {ok, Db} ->
             NewEntry = {
                 [
-                    {<<"target_node">>, atom_to_binary(node(), utf8)},
+                    {<<"target_node">>, atom_to_binary(config:node_name(), utf8)},
                     {<<"target_uuid">>, couch_db:get_uuid(Db)},
                     {<<"target_seq">>, couch_db:get_update_seq(Db)}
                 ] ++ NewEntry0
