@@ -206,7 +206,7 @@ profile(_Config, _Commands, Profiler) ->
 
 run_aux(BaseConfig, Commands) ->
     %% Make sure crypto is running
-    case crypto:start() of
+    case application:start(crypto) of
         ok -> ok;
         {error,{already_started,crypto}} -> ok
     end,
