@@ -15,20 +15,18 @@
 -module(rexi_server_mon).
 -behaviour(gen_server).
 -behaviour(mem3_cluster).
--vsn(1).
 
 -export([
     start_link/1,
-    status/0
+    status/0,
+    aggregate_queue_len/1
 ]).
 
 -export([
     init/1,
-    terminate/2,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3
+    handle_info/2
 ]).
 
 -export([
@@ -45,6 +43,17 @@ start_link(ChildMod) ->
 status() ->
     gen_server:call(?MODULE, status).
 
+aggregate_queue_len(rexi_buffer) ->
+    % rexi_buffer acts as an explicit message queue. In order to get useful
+    % metrics from it we really need to add both its process' message queue and
+    % already buffered messages.
+    ServerIds = server_ids(rexi_buffer),
+    MQLengths = [message_queue_len(ServerId) || ServerId <- ServerIds],
+    BufLengths = [rexi_buffer:get_buffered_count(ServerId) || ServerId <- ServerIds],
+    lists:sum(MQLengths) + lists:sum(BufLengths);
+aggregate_queue_len(ChildMod) ->
+    lists:sum([message_queue_len(ServerId) || ServerId <- server_ids(ChildMod)]).
+
 % Mem3 cluster callbacks
 
 cluster_unstable(Server) ->
@@ -69,9 +78,6 @@ init(ChildMod) ->
     couch_log:notice("~s : started servers", [ChildMod]),
     {ok, ChildMod}.
 
-terminate(_Reason, _St) ->
-    ok.
-
 handle_call(status, _From, ChildMod) ->
     case missing_servers(ChildMod) of
         [] ->
@@ -105,11 +111,6 @@ handle_info(Msg, St) ->
     couch_log:notice("~s ignored_info ~w", [?MODULE, Msg]),
     {noreply, St}.
 
-code_change(_OldVsn, nil, _Extra) ->
-    {ok, rexi_server};
-code_change(_OldVsn, St, _Extra) ->
-    {ok, St}.
-
 start_servers(ChildMod) ->
     lists:foreach(
         fun(Id) ->
@@ -162,3 +163,14 @@ stop_server(ChildMod, ChildId) ->
 
 sup_module(ChildMod) ->
     list_to_atom(lists:concat([ChildMod, "_sup"])).
+
+message_queue_len(ServerId) when is_atom(ServerId) ->
+    case whereis(ServerId) of
+        Pid when is_pid(Pid) ->
+            case process_info(Pid, message_queue_len) of
+                {message_queue_len, Length} -> Length;
+                undefined -> 0
+            end;
+        undefined ->
+            0
+    end.
